// ----------------------------------------------------------------------------
// This View handles About Dialog
// ----------------------------------------------------------------------------
AboutBella = new Class(
{
	Extends: DialogView,

	// ************************************************************************
	// ************************************************************************
	//     MEMBER VARIABLES
	// ************************************************************************
	// ************************************************************************

	_appState: null,
	_abouteNotify: null,
	_spriteImage: null,
	_accordion: null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return true;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function(){return [];},
	listCssAssets : function(){return [];},
	
	// ------------------------------------------------------------------------
	// This function returns a path to an optional html asset to load for this component
	// ------------------------------------------------------------------------
	listHtmlAsset : function(){return 'AboutBella.html';},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize: function () 
	{
		this.parent('AboutBella', this);
		this._appState = Facade.getInstance().retrieveProxy(AppState.NAME);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theDialogData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init: function (theBasePath, theDialogData) 
	{
		this.parent(theDialogData, 
		{
			basePath: theBasePath,
			title:  '',			// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			width: 540,
			height: 500,
			_ie_comma_safety: 0 // Keep as last option (doesn't have trailing comma)
		});
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded: function () 
	{
		this.parent();
		this._popUpWindow.setTitle(Skin.getInstance().getProductStyle('AboutDialogTitle'));
		this._widgetRootElement.getElement("#AboutBella_Intro").set("html", Skin.getInstance().getProductStyle("AboutBella_Intro"));
		this._widgetRootElement.getElement("#AboutBella_VersionTitle").set("html", Skin.getInstance().getProductStyle("AboutDialogVersionTitle"));
		this._widgetRootElement.getElement("#AboutBella_VersionText").set("html", CacheMgr.getInstance().getResourceVersion("CodeId"));
		this._widgetRootElement.getElement("#AboutBella_SupportTitle").set("html", Skin.getInstance().getProductStyle("AboutDialogSupportTitle"));
		this._widgetRootElement.getElement("#AboutBella_SupportText1").set("html", Skin.getInstance().getProductStyle("SupportNumber"));
		this._widgetRootElement.getElement("#AboutBella_SupportText2").set("html", Skin.getInstance().getProductStyle("SupportHours"));
		if (Skin.getInstance().get('AboutDialogImageUrl', '') != '')
		{
			this._widgetRootElement.getElement("#AboutBella_imageLink").setStyles({cursor: "pointer"});
			this._widgetRootElement.getElement("#AboutBella_imageLink").addEvent("click", this._onImageLink.bind(this));
			this._widgetRootElement.getElement(".AboutBella_footerLink").setStyles({cursor: "pointer"});
			this._widgetRootElement.getElement(".AboutBella_footerLink").addEvent("click", this._onImageLink.bind(this));
		}
		this._mooscroll = this._widgetRootElement.getElement('#accordion');
		this._mooTouchScroller = this._mooscroll.mooTouchAdd({'scroll':true});
		
		if (Browser.Platform.mobile)
		{
			this._widgetRootElement.getElement("#AboutBella_VersionTitle_m").set("html", Skin.getInstance().getProductStyle("AboutDialogVersionTitle"));
			this._widgetRootElement.getElement("#AboutBella_VersionText_m").set("html", CacheMgr.getInstance().getResourceVersion("CodeId"));
			this._widgetRootElement.getElement("#AboutBella_SupportTitle_m").set("html", Skin.getInstance().getProductStyle("AboutDialogSupportTitle"));
			this._widgetRootElement.getElement("#AboutBella_SupportText1_m").set("html", Skin.getInstance().getProductStyle("SupportNumber"));
			this._widgetRootElement.getElement("#AboutBella_SupportText2_m").set("html", Skin.getInstance().getProductStyle("SupportHours"));
		}
		
		this._abouteNotify = this._widgetRootElement.getElement('.btnAbouteNotify');
		this._abouteNotify = new SpriteButton(this._abouteNotify);
		this._abouteNotify.addEvent(SpriteButton.CLICK, this._onAbouteNotify.bind(this));

		this._onChangeLanguage();
		
		// Size the accordion control to fill the dialog minus the height of the bottom element
		var bottomSize = this._widgetRootElement.getElement('#AboutBella_bottom').getSize();
		this._widgetRootElement.getElement('#accordion').setStyles(
		{
			'top': 0,
			'left' : 0,
			'right' : 0,
			'bottom' : bottomSize.y
		});
		
		// Get the top corner radius and use for the bottom corner radius of the bottom element
		// I do this so that the popUpWindow skin settings for the dialog radius will be honored here
		var theHeaderElement = this._widgetRootElement.getElement('.popUpWindow.AboutBella .header');
		var theCornerRadius = theHeaderElement.getStyle('border-top-left-radius');
		this._widgetRootElement.getElement('#AboutBella_bottom').setStyles(
		{
			'border-bottom-left-radius':theCornerRadius,
			'border-bottom-right-radius':theCornerRadius
		});

		this._show();
	},

	// ************************************************************************
	// ************************************************************************
	//
	// ************* Add Custom Functions and Event Handlers here *************
	//
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// Event handler for the click event on the image link
	// ------------------------------------------------------------------------


	_onChangeLanguage: function () 
	{
		var T1 = Skin.getInstance().getProductStyle('AboutBella_Accordion_eNotify_Title', '');
		if (T1 != '')
		{
			this._spriteImage = Skin.getInstance().getPath('AboutBella_eNotify_Sprite', '', Skin.PRODUCT_STYLE) + CacheMgr.getInstance().getResourceCacheArg('RelId', '&');
			this._abouteNotify.setImage(this._spriteImage, {ImgIndex: AboutBella.ENOTIFY_SPRITE});
		}
		
		var T2 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title2', '');
		var T3 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title3', '');
		var T4 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title4', '');
		var T5 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title5', '');
		var T6 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title6', '');
		var T7 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title7', '');
		var T8 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title8', '');
		var T9 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title9', '');
		var T10 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title10', '');
		var T11 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title11', '');
		var T12 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title12', '');
		var T13 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Title13', '');
		var X1 = Skin.getInstance().getProductStyle('AboutBella_eNotify_Text', '');
		var X2 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text2', '');
		var X3 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text3', '');
		var X4 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text4', '');
		var X5 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text5', '');
		var X6 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text6', '');
		var X7 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text7', '');
		var X8 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text8', '');
		var X9 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text9', '');
		var X10 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text10', '');
		var X11 = Skin.getInstance().getProductStyle('AboutBella_Accordion_Text11', '');			

		if (T1 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title1").hide();
			this._widgetRootElement.getElement("#accordion_1").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title1 span").set('html', T1 ).show();
		if (T2 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title2").hide();
			this._widgetRootElement.getElement("#accordion_2").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title2 span").set('html', T2 ).show();
		if (T3 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title3").hide();
			this._widgetRootElement.getElement("#accordion_3").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title3 span").set('html', T3 ).show();
		if (T4 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title4").hide();
			this._widgetRootElement.getElement("#accordion_4").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title4 span").set('html', T4 ).show();
		if (T5 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title5").hide();
			this._widgetRootElement.getElement("#accordion_5").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title5 span").set('html', T5 ).show();
		if (T6 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title6").hide();
			this._widgetRootElement.getElement("#accordion_6").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title6 span").set('html', T6 ).show();
		if (T7 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title7").hide();
			this._widgetRootElement.getElement("#accordion_7").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title7 span").set('html', T7 ).show();
		if (T8 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title8").hide();
			this._widgetRootElement.getElement("#accordion_8").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title8 span").set('html', T8 ).show();
		if (T9 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title9").hide();
			this._widgetRootElement.getElement("#accordion_9").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title9 span").set('html', T9 ).show();
		if (T10 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title10").hide();
			this._widgetRootElement.getElement("#accordion_10").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title10 span").set('html', T10 ).show();
		if (T11 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title11").hide();
			this._widgetRootElement.getElement("#accordion_11").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title11 span").set('html', T11 ).show();
		if (T12 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title12").hide();
			this._widgetRootElement.getElement("#accordion_12").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title12 span").set('html', T12 ).show();
		if (T13 == '')
		{
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title13").hide();
			this._widgetRootElement.getElement("#accordion_13").hide();
		}
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Title13 span").set('html', T13 ).show();
			
			
		if (X1 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text1").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_eNotify_Text").set('html', X1 ).show();
		if (X2 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text2").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text2 span").set('html', '<li>' + X2 ).show();
		if (X3 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text3").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text3 span").set('html', '<li>' + X3 ).show();
		if (X4 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text4").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text4 span").set('html', '<li>' + X4 ).show();
		if (X5 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text5").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text5 span").set('html', '<li>' + X5 ).show();
		if (X6 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text6").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text6 span").set('html', '<li>' + X6 ).show();
		if (X7 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text7").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text7 span").set('html', '<li>' + X7 ).show();
		if (X8 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text8").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text8 span").set('html', '<li>' + X8 ).show();
		if (X9 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text9").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text9 span").set('html', '<li>' + X9 ).show();
		if (X10 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text10").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text10 span").set('html', '<li>' + X10 ).show();
		if (X11 == '')
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text11").hide();
		else
			this._widgetRootElement.getElement("#AboutBella_Accordion_Text11 span").set('html', '<li>' + X11 ).show();				
	},

	_onAbouteNotify: function (e) 
	{
		// Close this modal about dialog before openning the eNotify modal dialog
		this.onClose();
		
		this._aboutState = AboutBella.ENOTIFY_SPRITE;
		Facade.getInstance().sendNotification(ApplicationFacade.LOAD_COMPONENT, 
		{
			Name: 'eNotify',
			HasCss: true,
			Data: null,
		});

	},

	_onImageLink: function () 
	{
		var a;
		a = Skin.getInstance().get("AboutDialogImageUrl");
		Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, 
		{
			link: a,
			target: "_blank",
			source: "Link"
		});
	},

	_ie_comma_safety: 0 // Keep as last member of class (doesn't have trailing comma)
});

// ****************************************************************************
// ****************************************************************************
// Constants used define the horizontal ordering of the button images in the sprite
// ****************************************************************************
// ****************************************************************************

AboutBella.ENOTIFY_SPRITE = 0;