// ----------------------------------------------------------------------------
// This View handles the Template Component
// ----------------------------------------------------------------------------
MMMCart = new Class(
{
   Extends : DialogView,

	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	
	
	_items : new Array(),
	_theLanguageCode : null,
	_theCompanyCode : null,
	_theBookCode : null,
	_previewShareMode : null,
	_previewCheckoutMode : null,
	_toEmail : null,
	_fromEmail : null,
	_msgEmail : null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('MMMCart', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theDialogData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theDialogData)
    {		
		this.parent(theDialogData,
		{
			basePath : theBasePath,
			title:  Skin.getInstance().get('MMMCartDialogTitle', ''),	// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			width:  748,
			height: 600,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		this.parent();

		//ELEMENTS
		this._cartPanel = this._widgetRootElement.getElement('#MMMCart-panel-cart');
		this._cartFooter = this._widgetRootElement.getElement('#MMMCart-footer-cart');
		this._checkoutPanel = this._widgetRootElement.getElement('#MMMCart-panel-checkout');
		this._checkoutFooter = this._widgetRootElement.getElement('#MMMCart-footer-checkout');
		this._sharePanel = this._widgetRootElement.getElement('#MMMCart-panel-share');
		this._shareFooter = this._widgetRootElement.getElement('#MMMCart-footer-share');

		//BUTTONS
		this._continueBtn = this._widgetRootElement.getElements('.btn-continue');
		this._continueBtn.addEvent('click', this.onClose.bind(this));
		this._checkoutBtn = this._widgetRootElement.getElement('.btn-checkout');
		this._checkoutBtn.addEvent('click', this._onClickCheckout.bind(this));
		this._shareBtn = this._widgetRootElement.getElement('.btn-share');
		this._shareBtn.addEvent('click', this._onClickShare.bind(this));
		this._sharePreview = this._widgetRootElement.getElement('.btn-share-preview');
		this._sharePreview.addEvent('click', this._sendShare.bind(this));
		this._shareSend = this._widgetRootElement.getElement('.btn-share-send');
		this._shareSend.addEvent('click', this._sendShare.bind(this));
		this._clearBtn = this._widgetRootElement.getElements('.btn-clear');
		this._clearBtn.addEvent('click', this._onClickClear.bind(this));
		this._backBtn = this._widgetRootElement.getElements('.btn-back');
		this._backBtn.addEvent('click', this._onClickBack.bind(this));
		this._checkoutNextBtn = this._widgetRootElement.getElements('.btn-checkout-next');
		this._checkoutNextBtn.addEvent('click', this._onClickNextCheckout.bind(this));
		this._checkoutBackBtn = this._widgetRootElement.getElements('.btn-checkout-back');
		this._checkoutBackBtn.addEvent('click', this._onClickBackCheckout.bind(this));

		this._checkoutPreviewBtn = this._widgetRootElement.getElement('.btn-checkout-preview');
		this._checkoutPreviewBtn.addEvent('click', this._sendCheckout.bind(this));
		this._checkoutSendBtn = this._widgetRootElement.getElement('.btn-checkout-send');
		this._checkoutSendBtn.addEvent('click', this._sendCheckout.bind(this));

		this._requiredInput = this._widgetRootElement.getElements('[required]');
		this._requiredInput.addEvent('blur', this._onBlurRequired.bind(this));

		this._items = Preferences.getInstance().get('Cart');
		if (this._items === undefined)
			this._items = [];

		this._onClickAddItem();
		this._displayItems();

		if (typeof jQuery != 'undefined')
		{ 
			(function(jQuery)
			{ 
				jQuery(document).ready(function()
				{
					jQuery('.carousel').each(function(index, element)
					{
						jQuery(this)[index].slide = null;
					});
				});
			})(jQuery);
		}

		appViewSize = this._applicationViewElement.measure(function(){return this.getSize();});
		if (Browser.Platform.mobile)
		{
			jQuery('.popUpWindow.MMMCart').css('height',appViewSize.y);
			jQuery('.panel.panel-default').css('height',appViewSize.y-104);
		}
		this._onChangeLanguage();
		this._updateCount();
		this._show();

		var theLanguageList, theLanguageIndex;
		theLanguageList = this._appState.get(currentLanguageList);
		theLanguageIndex = this._appState.get(currentLanguageIndex);
		this._theLanguageCode = theLanguageList.getLanguageCode(theLanguageIndex);	
		this._theCompanyCode = Skin.getInstance().get('DefaultCompanyCode');
	},

	// ************************************************************************
	// ************************************************************************
	//
	// ************* Add Custom Functions and Event Handlers here *************
	//
	// ************************************************************************
	// ************************************************************************

	_onClickBack : function(event)
	{
		this._cartPanel.show();
		this._cartFooter.show();
		this._checkoutPanel.hide();
		this._checkoutFooter.hide();
		this._sharePanel.hide();
		this._shareFooter.hide();
		this._previewShareMode = null;
		this._previewCheckoutMode = null;
	},

	_onClickCheckout : function(event)
	{
		this._cartPanel.hide();
		this._cartFooter.hide();
		this._checkoutPanel.show();
		this._checkoutFooter.show();
		this._sharePanel.hide();
		this._shareFooter.hide();
		var CheckoutForm = (Skin.getInstance().get('MMMCartForm', ''));
		var CheckoutFormDebug = (Skin.getInstance().get('MMMCartDebugForm', ''));
		if ((Skin.getInstance().get('MMMCart_DebugForm')) === 'test')
			jQuery('#MMMCart-carousel-container').load(this._getBasePath()+'languages/'+this._theLanguageCode+'/'+CheckoutFormDebug);
		else
			jQuery('#MMMCart-carousel-container').load(this._getBasePath()+'languages/'+this._theLanguageCode+'/'+CheckoutForm);

		var delay = 100;
		setTimeout(function()
		{
			var carouselItems = jQuery('.carousel-inner .item').length;
			jQuery('#MMMCart-carousel-indicators').empty();
			jQuery('#MMMCart-carousel-indicators').each(function()
			{
				for(i = 0; i < carouselItems; i++)
				{
					jQuery('<li class="">'+(i+1)+'</li>').appendTo(this);
				}
			});
			jQuery('#MMMCart-carousel-indicators li:first').addClass('active');
			jQuery('#MMMCart-button-checkout').attr('form', 'MMMCart-form-panel-1');
		}, delay);
		jQuery('.btn-checkout-preview').hide();
		jQuery('.btn-checkout-send').hide();
		jQuery('.btn-checkout-next').show();
	},

	_onClickBackCheckout : function(event)
	{
		if ((jQuery('.carousel-inner .item:first').hasClass('active')) || (jQuery('#MMMCart-form-checkout-success').is(':visible')) || (jQuery('.btn-checkout-send').is(':visible')))
		{
			this._cartPanel.show();
			this._cartFooter.show();
			this._checkoutPanel.hide();
			this._checkoutFooter.hide();
			this._sharePanel.hide();
			this._shareFooter.hide();
			this._previewCheckoutMode = null;
		}
		else
		{
			jQuery('.btn-checkout-preview').hide();
			jQuery('.btn-checkout-send').hide();
			jQuery('.btn-checkout-next').show();
			var delay = 500;
			setTimeout(function()
			{
				var formID = jQuery('form.active').attr('id');
				jQuery('#MMMCart-button-checkout').attr('form', formID);
			}, delay);
		}
	},

	_onClickNextCheckout : function(event)
	{
		document.getElementById("MMMCart-form-match2").setCustomValidity('');
		var validCheck = jQuery('form.active')[0].checkValidity();
		var matchCheck1 = jQuery('#MMMCart-form-match1').val();
		var matchCheck2 = jQuery('#MMMCart-form-match2').val();
		if (validCheck === true)
		{
			if (matchCheck1 == matchCheck2)
			{
				jQuery('.carousel').carousel('next');
				if (jQuery('.carousel-inner .item:nth-last-child(2)').hasClass('active'))
				{
					if (Browser.Platform.desktop)
					{
						jQuery('.btn-checkout-next').hide();
						jQuery('.btn-checkout-send').hide();
						jQuery('.btn-checkout-preview').show();
					}
					else
					{
						this._previewCheckoutMode = false;
						jQuery('.btn-checkout-next').hide();
						jQuery('.btn-checkout-preview').hide();
						jQuery('.btn-checkout-send').show();
					}
				}
				var delay = 500;
				setTimeout(function()
				{
					var formID = jQuery('form.active').attr('id');
					jQuery('#MMMCart-button-checkout').attr('form', formID);
				}, delay);
			}
			else
				document.getElementById("MMMCart-form-match2").setCustomValidity('Email addresses do not match.');
		}
	},

	_onClickShare : function(event)
	{
		this._previewShareMode = null;
		this._cartPanel.hide();
		this._cartFooter.hide();
		this._checkoutPanel.hide();
		this._checkoutFooter.hide();
		this._sharePanel.show();
		this._shareFooter.show();
		jQuery('#MMMCart-form-share-preview').hide();
		jQuery('#MMMCart-form-share-success').hide();
		jQuery('#MMMCart-form-share-form').show();
		jQuery('#MMMCart-form-share')[0].reset();
		if (Browser.Platform.desktop)
		{
			jQuery('.btn-share-send').hide();
			jQuery('.btn-share-preview').show();
		}
		else
		{
			this._previewShareMode = false;
			jQuery('.btn-share-preview').hide();
			jQuery('.btn-share-send').show();
		}
		jQuery('#MMMCart_DialogContent input[required]').css('border-left-color','#d9534f');
	},

	_onClickClear : function(event)
	{
		jQuery(event.target).siblings('.form-btn').val('');
		if (jQuery(event.target).siblings('.form-btn').is('[required]'))
			jQuery(inputElement).css('border-left', '3px solid #d9534f');
	},

	_onBlurRequired : function(event)
	{
		inputElement = event.target;
		var validCheck = jQuery(inputElement)[0].checkValidity();
		if (validCheck === true)
			jQuery(inputElement).css('border-left', '3px solid #5cb85c');
		else
			jQuery(inputElement).css('border-left', '3px solid #d9534f');
	},

	_onClickTab : function(event)
	{
		var target = jQuery(event.target);
		var targetParent = target.parent()[0];
		var targetContainer = target.attr('href');
		jQuery('.openTab').not(targetParent).removeClass('openTab');
		jQuery(targetContainer).toggleClass('active');
		jQuery(targetParent).toggleClass('openTab');
	},

	onClose : function()
	{
		Facade.getInstance().removeMediator(this.mediatorName);
		this._popUpWindow.onClose();
		(function()
		{
			// This cancel is necessary to avoid an error in IE8
			this._popUpWindow.getWindowDiv().get('tween').cancel();
			this._widgetRootElement.destroy();
		}).delay(250, this);

		Preferences.getInstance().flush();
		this.parent();
	},

	_onClickAddItem : function(event)
	{
		if (!this._data)
			return;

		this._MMMCartAttribute1 = (Skin.getInstance().get('MMMCart_Attribute_1', ''));
		this._MMMCartAttribute2 = (Skin.getInstance().get('MMMCart_Attribute_2', ''));
		this._MMMCartAttribute3 = (Skin.getInstance().get('MMMCart_Attribute_3', ''));
		this._MMMCartAttribute4 = (Skin.getInstance().get('MMMCart_Attribute_4', ''));
		this._MMMCartAttribute5 = (Skin.getInstance().get('MMMCart_Attribute_5', ''));

		var theBook = this._appState.get(currentBook);
		var theBookList = this._appState.get(currentBookList);
		var theBookIndex = theBookList.getBookListIndex(theBook.bookCode);
		var theBookListEntry = theBookList.getBookListEntry(theBookIndex);
		var theBookPageIndex = this._appState.get(currentBookPageDest).BookPageIndex;
		var theBookTitle =  theBookListEntry.title;
		var theBookCover = theBookListEntry.thumbnailBig;
		var theBookCoverUrl = theBookListEntry.getBookFolder(false) + theBookListEntry.thumbnailBig;
		var bookpath = REMOTE_PATH_TO_SERVICES;
		var bookcode = theBook.bookCode;
		var booktitle = theBookTitle;
		var bookcover = theBookCoverUrl;
		var pagelabel = theBook.getPageLabel(theBookPageIndex);
		var productpath = bookpath+'app.php?BookCode='+bookcode+'&PageLabel='+pagelabel;
		var attr1 = this._data.find(this._MMMCartAttribute1).text();
		var attr2 = this._data.find(this._MMMCartAttribute2).text();
		var attr3 = this._data.find(this._MMMCartAttribute3).text();
		var attr4 = this._data.find(this._MMMCartAttribute4).text();
		var attr5 = this._data.find(this._MMMCartAttribute5).text();

		var qtyElement = this._widgetRootElement.getElementById('MMMCart_Qty');
		if (qtyElement === null)
			var qty = '1';
		else
			var qty = qtyElement.value;

		var notInList = true;
		for (var i = 0; i < this._items.length; i++)
		{
			if ((this._items[i].attr1 == attr1) && (this._items[i].attr2 == attr2))
			{
				notInList = false;
				var curQty = parseFloat(this._items[i].qty);
				this._items[i].qty = (curQty + 1);
			}
		}
		if (notInList)
		{
			this._items.unshift({
				bookpath:bookpath,
				bookcode:bookcode,
				booktitle:booktitle,
				bookcover:bookcover,
				pagelabel:pagelabel,
				productpath:productpath,
				attr1:attr1,
				attr2:attr2,
				attr3:attr3,
				attr4:attr4,
				attr5:attr5,
				qty:qty
			});
		}
		Preferences.getInstance().set('Cart', this._items);
	},

	_displayItems : function()
	{
		var currency_label = (Skin.getInstance().get('MMMCart_Currency_Label', ''));
		var attr1_label = (Skin.getInstance().get('MMMCart_Attribute_1_Label', ''));
		var attr2_label = (Skin.getInstance().get('MMMCart_Attribute_2_Label', ''));
		var attr3_label = (Skin.getInstance().get('MMMCart_Attribute_3_Label', ''));
		var attr4_label = (Skin.getInstance().get('MMMCart_Attribute_4_Label', ''));
		var attr5_label = (Skin.getInstance().get('MMMCart_Attribute_5_Label', ''));
		var tab1_label = (Skin.getInstance().get('MMMCart_Tab_1_Label', ''));
		var tab2_label = (Skin.getInstance().get('MMMCart_Tab_2_Label', ''));

		var itemsText = '';
		for (var i = 0; i < this._items.length; i++)
		{
			itemsText += '<div class="row item-wrapper">';
			itemsText += '    <div class="MMMCart_ProductImage col-sm-2 hidden-xs"><a href="'+this._items[i].productpath+'"><img class="img-responsive" src="'+this._getBasePath()+'logo.png"></div></a>';
			itemsText += '    <div id="MMMCart_Wrapper_Attribute_1" class="col-sm-7 col-xs-7">';
			itemsText += '        <h5><strong id="MMMCart_Attribute_1">'+attr1_label+''+this._items[i].attr1+'</strong></h5>';
			itemsText += '        <h4><small id="MMMCart_Attribute_2">'+attr2_label+''+this._items[i].attr2+'</small></h4>';
			if (this._items[i].attr3)
			{
				itemsText += '        <h4><small id="MMMCart_Attribute_3">'+attr3_label+''+this._items[i].attr3+'</small></h4>';
			}
			itemsText += '        <ul class="nav nav-tabs" role="tablist">';
			itemsText += '            <li role="presentation">';
			itemsText += '                <a class="btn-tab" href="#tab-section" aria-controls="tab-section" role="tab" data-toggle="tab" aria-expanded="false">'+tab1_label+'</a>';
			itemsText += '            </li>';
			itemsText += '            <li role="presentation">';
			itemsText += '                <a class="btn-tab" href="#tab-section" aria-controls="tab-section" role="tab" data-toggle="tab" aria-expanded="false">'+tab2_label+'</a>';
			itemsText += '            </li>';
			itemsText += '        </ul>';
			itemsText += '    </div>';
			itemsText += '    <div class="col-sm-3 col-xs-5">';
			itemsText += '        <div id="MMMCart_Wrapper_Qty" class="col-xs-6">';
			itemsText += '            <input id="MMMCart_Qty_'+i+'" type="text" class="cart-qty form-btn form-control input-sm" value="'+this._items[i].qty+'">';
			itemsText += '        </div>';
			itemsText += '        <div id="MMMCart_Wrapper_RemoveBtn" class="col-xs-2">';
			itemsText += '            <button id="cart_item_'+i+'" class="btn btn-danger btn-sm btn-remove">';
			itemsText += '                <i class="glyphicon glyphicon-trash"></i>';
			itemsText += '            </button>';
			itemsText += '        </div>';
			itemsText += '    </div>';
			itemsText += '    <div class="tab-content col-xs-12 col-sm-12 col-md-12 col-lg-12">';
			itemsText += '        <div class="tab-pane fade in" id="tab-section" role="tabpanel">';
			itemsText += '            <div id="MMMCart_Attribute_4" class="well">'+attr4_label+''+this._items[i].attr4+'</div>';
			itemsText += '        </div>';
			itemsText += '        <div class="tab-pane fade" id="tab-section" role="tabpanel">';
			itemsText += '            <div class="well">';
			itemsText += '                <ul id="MMMCart_Attribute_5">'+attr5_label+''+this._items[i].attr5+'</ul>';
			itemsText += '            </div>';
			itemsText += '        </div>';
			itemsText += '    </div>';
			itemsText += '</div>';
		}
		this._listElement = this._widgetRootElement.getElement('#MMMCart-panel-cart');
		this._listElement.set('html', itemsText);
		this._doFormSelect(this._listElement);
		this._tabBtn = this._widgetRootElement.getElements('.btn-tab');
		this._tabBtn.addEvent('click', this._onClickTab.bind(this));
		this._removeBtn = this._widgetRootElement.getElements('.btn-remove');
		this._removeBtn.addEvent('click', this._onClickRemove.bind(this));
		this._removeBtnIcn = this._widgetRootElement.getElements('.glyphicon-trash');
		this._removeBtnIcn.addEvent('click', this._onClickRemove.bind(this));
		this._emptyCheck();

		//Loop through quantity events
		theElementList = this._listElement.getElements('.cart-qty');
		theElementList.each(function(item, index)
		{
			item.mooTouchRemove();
			item.mooTouchAdd({'click':true});
			item.addEvent('click',function(event){event.target.select();event.target.focus()});
			item.addEvent('change', this._changeQty.bind(this));
			
		}.bind(this));


		//ASSIGNS ID# TO MATCH TAB BUTTONS WITH TAB CONTAINERS
		for (i = 1; i <= jQuery('.tab-pane').length; i++)
		{
			jQuery('.tab-pane').each(function(i) {
	            jQuery(this).attr('id', 'cart-tab'+i);
	      	});
			jQuery('li .btn-tab').each(function(i) {
	            jQuery(this).attr('href', '#cart-tab'+i);
	            jQuery(this).attr('aria-controls', 'cart-tab'+i);
	      	});
      	}
	},

	_changeQty : function(event)
	{
		var theItem = event.target;
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		var newQty = jQuery(event.target).closest('.cart-qty').val();
		if (newQty === "0")
			this._onClickRemove(event);
		this._items[theItemId].qty = newQty;
		this._updateCount();
		this._emptyCheck();
	},
	
	_onClickRemove : function(event)
	{
		var theItem = event.target;
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		jQuery(event.target).closest('.item-wrapper').remove();
		this._items.splice(theItemId, 1);
	//	Preferences.getInstance().flush();
		this._updateCount();
		this._displayItems();
	},

	_updateCount : function()
	{
		var currency_label = (Skin.getInstance().get('MMMCart_Currency_Label', ''));
		var cnt = 0;
		this._items.each(function(item, index)
		{
			cnt += Number(item.qty);
		});
		this._appState.set(cartListCnt, cnt);
	//	Preferences.getInstance().flush();
		this._listElement = this._widgetRootElement.getElement('#MMMCart-panel-cart');
	/*
		var priceTotal = 0;
		for (var i = 0; i < this._items.length; i++)
		{
			priceTotal += Number(this._items[i].attr3)*Number(this._items[i].qty);
		}
		this._widgetRootElement.getElement('.total-sum strong').set('html', ''+currency_label+''+(priceTotal.toFixed(2)));
	*/
	},

	_emptyCheck : function()
	{
		this._listElement = this._widgetRootElement.getElement('#MMMCart-panel-cart');
		if (this._items.length == 0)
		{
			this._listElement.set('html', (Skin.getInstance().get('MMMCart_EmptyMsg', 'Project List is Empty')));
			this._listElement.addClass('cart-empty');
		}
		else
		{
			this._listElement.removeClass('cart-empty');
		}
	},

	_previewShare : function(postShareInfoArr,postShareItemsArr,url)
	{
	//	console.log('_previewShare');
		jQuery('#MMMCart-form-share-form').hide();
		jQuery('#MMMCart-form-share-preview').show();
		jQuery('#MMMCart-form-share-preview').html('<iframe id="previewShareFrame" name="previewShareFrame" width="100%" height="500px" seamless="seamless" scrolling="yes" frameborder="0"></iframe>');
		jQuery('body').append('<form action="'+url+'" method="post" target="previewShareFrame" id="postToIframe"></form>');
		
		jQuery('#postToIframe').append('<input type="hidden" name="previewShare" value="'+this._previewShareMode+'" />');

		jQuery.each(postShareInfoArr[0], function(i, v){
			jQuery('#postToIframe').append('<input type="hidden" name="Info[0]['+i+']" value="'+v+'" />');
			//console.log( "Name: " + i + ", Value: " + v );
		});
		jQuery.each(postShareItemsArr, function(n, j){
			jQuery.each(postShareItemsArr[n], function(i2, v2){
				jQuery('#postToIframe').append('<input type="hidden" name="Items['+n+']['+i2+']" value="'+v2+'" />');
				//console.log( "Name: " + i2 + ", Value: " + v2 );
			});
		});
		jQuery('#postToIframe').submit().remove();
		jQuery('.btn-share-preview').hide();
		jQuery('.btn-share-send').show();
	},

	_sendShare : function()
	{
	//	console.log('_sendShare');
		var validCheck = jQuery('#MMMCart-form-share')[0].checkValidity();
		if (validCheck === true)
		{
			if (this._previewShareMode == null)
				this._previewShareMode = true;

			var logoPath = REMOTE_PATH_TO_SERVICES+'skin/images/'+(Skin.getInstance().get('MMMCart_Logo', 'logo_small.png'));
			if ((this._previewShareMode == true) || (!Browser.Platform.desktop))
			{
				this._toEmail = jQuery('#MMMCart-form-share-to').val();
				this._fromEmail = jQuery('#MMMCart-form-share-from').val();
				this._companyEmail = jQuery('#MMMCart-form-share-company').val();
				this._nameEmail = jQuery('#MMMCart-form-share-name').val();
				this._msgEmail = jQuery('#MMMCart-form-share-msg').val();
			}
			var pathToCode = this._getBasePath();
			var postShareInfoArr = [];
			var postShareItemsArr = [];

			postShareInfoArr.push(
			{
				"lang":this._theLanguageCode,
				"CompanyCode":this._theCompanyCode,
				"BookCode":this._theBookCode,
				"logoPath":logoPath,
				"toEmail":this._toEmail,
				"fromEmail":this._fromEmail,
				"companyEmail":this._companyEmail,
				"nameEmail":this._nameEmail,
				"msgEmail":this._msgEmail
			});
			for (var i = 0; i < this._items.length; i++)
			{
			    postShareItemsArr.push(
			    {
			    	bookpath: this._items[i].bookpath,
			    	pagelabel: this._items[i].pagelabel,
			    	productpath: this._items[i].productpath,
			    	bookcover: this._items[i].bookcover,
			        attr1: this._items[i].attr1,
			        attr2: this._items[i].attr2,
					attr3: this._items[i].attr3,
					attr4: this._items[i].attr4,
					attr5: this._items[i].attr5,
					qty: this._items[i].qty
			    });
			}

			this._previewShare(postShareInfoArr, postShareItemsArr, pathToCode+'ServiceEmailList.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?'));
			if (this._previewShareMode == true)
				this._previewShareMode = false;
			else
			{
			//	this._toEmail = this._fromEmail = this._msgEmail = null;
				this._sendShareSent();
			}
		}
	},

	_sendShareSent : function()
	{
		jQuery('.btn-share-send').hide();
		jQuery('#MMMCart-form-share-preview').hide();
		jQuery('#MMMCart-form-share-form').hide();
		jQuery('#MMMCart-form-share-success').show();
	},

	//CHECKOUT
	_previewCheckout : function(postCheckoutInfoArr,postCheckoutItemsArr,url)
	{
	//	console.log('_previewCheckout');
		jQuery('#MMMCart-form-checkout-form').hide();
		jQuery('#MMMCart-carousel-indicators').hide();
		jQuery('#MMMCart-form-checkout-preview').show();
		jQuery('#MMMCart-form-checkout-preview').html('<iframe id="previewCheckoutFrame" name="previewCheckoutFrame" width="100%" height="500px" seamless="seamless" scrolling="yes" frameborder="0"></iframe>');
		jQuery('body').append('<form action="'+url+'" method="post" target="previewCheckoutFrame" id="postToIframe"></form>');
		
		jQuery('#postToIframe').append('<input type="hidden" name="previewCheckout" value="'+this._previewCheckoutMode+'" />');

		jQuery.each(postCheckoutInfoArr[0], function(i, v){
			jQuery('#postToIframe').append('<input type="hidden" name="Info[0]['+i+']" value="'+v+'" />');
			//console.log( "Name: " + i + ", Value: " + v );
		});
		jQuery.each(postCheckoutItemsArr, function(n, j){
			jQuery.each(postCheckoutItemsArr[n], function(i2, v2){
				jQuery('#postToIframe').append('<input type="hidden" name="Items['+n+']['+i2+']" value="'+v2+'" />');
				//console.log( "Name: " + i2 + ", Value: " + v2 );
			});
		});
		jQuery('#postToIframe').submit().remove();
		jQuery('.btn-checkout-preview').hide();
		jQuery('.btn-checkout-next').hide();
		jQuery('.btn-checkout-send').show();
	},

	_sendCheckout : function()
	{
		var validCheck = jQuery('.carousel-inner .item:nth-last-child(2)')[0].checkValidity();
		if (validCheck === true)
		{
			var logoPath = REMOTE_PATH_TO_SERVICES+'skin/images/'+(Skin.getInstance().get('MMMCart_Logo', 'logo_small.png'));
			if (this._coEmail == null)
			{
				this._toEmail = 'michael.klund@dirxion.com';
				this._fromEmail = 'michael.klund@dirxion.com';
				this._msgEmail = 'MessageTest';
				this._coCompany = jQuery('input[name="company"]').val();
				this._coContact = jQuery('input[name="name"]').val();
				this._coProject = jQuery('input[name="project"]').val();
				this._coPhone = jQuery('input[name="tel"]').val();
				this._coEmail = jQuery('input[name="email"]').val();
				this._coConfirmEmail = jQuery('input[name="confirmemail"]').val();
				this._coAccount = jQuery('input[name="account"]').val();
				this._coAddress = jQuery('input[name="street-address"]').val();
				this._coCity = jQuery('input[name="city"]').val();
				this._coState = jQuery('input[name="state"]').val();
				this._coPostal = jQuery('input[name="postal-code"]').val();
				this._coCountry = jQuery('input[name="country-name"]').val();
			}
			var pathToCode = this._getBasePath();
			var postCheckoutInfoArr = [];
			var postCheckoutItemsArr = [];
			
			if (this._previewCheckoutMode == null)
				this._previewCheckoutMode = true;

			postCheckoutInfoArr.push(
			{
				"lang":this._theLanguageCode,
				"CompanyCode":this._theCompanyCode,
				"BookCode":this._theBookCode,
				"logoPath":logoPath,
				"toEmail":this._toEmail,
				"fromEmail":this._fromEmail,
				"msgEmail":this._msgEmail,
				"coCompany":this._coCompany,
				"coContact":this._coContact,
				"coProject":this._coProject,
				"coPhone":this._coPhone,
				"coEmail":this._coEmail,
				"coAccount":this._coAccount,
				"coAddress":this._coAddress,
				"coCity":this._coCity,
				"coState":this._coState,
				"coPostal":this._coPostal,
				"coCountry":this._coCountry
			});
			for (var i = 0; i < this._items.length; i++)
			{
			    postCheckoutItemsArr.push(
			    {
			    	bookpath: this._items[i].bookpath,
			    	pagelabel: this._items[i].pagelabel,
			    	productpath: this._items[i].productpath,
			    	bookcover: this._items[i].bookcover,
			        attr1: this._items[i].attr1,
			        attr2: this._items[i].attr2,
					attr3: this._items[i].attr3,
					attr4: this._items[i].attr4,
					attr5: this._items[i].attr5,
					qty: this._items[i].qty
			    });
			}

			this._previewCheckout(postCheckoutInfoArr, postCheckoutItemsArr, pathToCode+'ServiceCheckOut.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?'));
			if (this._previewCheckoutMode == true)
				this._previewCheckoutMode = false;
			else
			{
				this._toEmail = this._fromEmail = this._msgEmail = null;
				this._sendCheckoutSent();
			}
		}
	},

	_sendCheckoutSent : function()
	{
		jQuery('#MMMCart-button-checkout').hide();
		jQuery('#MMMCart-form-checkout-preview').hide();
		jQuery('#MMMCart-form-checkout-form').hide();
		jQuery('#MMMCart-carousel-indicators').hide();
		jQuery('.btn-checkout-send').hide();
		jQuery('#MMMCart-form-checkout-success').show();
	},

	_onChangeLanguage : function () 
	{
		jQuery('#MMMCart_DialogContent .lang-checkout-btn').html((Skin.getInstance().get('MMMCart-lang-checkout-btn', 'Request Quote')));
		jQuery('#MMMCart_DialogContent .lang-total-sum').html((Skin.getInstance().get('MMMCart-lang-total-sum', 'Total <strong>$75.00</strong>')));
		jQuery('#MMMCart_DialogContent .lang-share-btn').html((Skin.getInstance().get('MMMCart-lang-share-btn', 'Share Quote')));
		jQuery('#MMMCart_DialogContent .lang-back-btn').html((Skin.getInstance().get('MMMCart-lang-back-btn', 'Back')));
		jQuery('#MMMCart_DialogContent .lang-next-btn').html((Skin.getInstance().get('MMMCart-lang-next-btn', 'Next')));
		jQuery('#MMMCart_DialogContent .lang-preview-btn').html((Skin.getInstance().get('MMMCart-lang-preview-btn', 'Preview')));
		jQuery('#MMMCart_DialogContent .lang-send-btn').html((Skin.getInstance().get('MMMCart-lang-send-btn', 'Send')));
		jQuery('#MMMCart_DialogContent .lang-summary-btn').html((Skin.getInstance().get('MMMCart-lang-summary-btn', 'Quote Summary')));
		jQuery('#MMMCart_DialogContent .lang-confirm-btn').html((Skin.getInstance().get('MMMCart-lang-confirm-btn', 'Confirm Quote')));

		jQuery('#MMMCart_DialogContent .lang-share-sent').html((Skin.getInstance().get('MMMCart-lang-share-sent', 'Your email was successfully sent.')));
		jQuery('#MMMCart_DialogContent .lang-share-from').html((Skin.getInstance().get('MMMCart-lang-share-from', 'From:')));
		jQuery('#MMMCart_DialogContent .lang-share-to').html((Skin.getInstance().get('MMMCart-lang-share-to', 'To:')));
		jQuery('#MMMCart_DialogContent .lang-share-company').html((Skin.getInstance().get('MMMCart-lang-share-company', 'Company:')));
		jQuery('#MMMCart_DialogContent .lang-share-name').html((Skin.getInstance().get('MMMCart-lang-share-name', 'Name:')));
		jQuery('#MMMCart_DialogContent .lang-placeholder-from').attr('placeholder',(Skin.getInstance().get('MMMCart-lang-placeholder-from', 'From Email')));
		jQuery('#MMMCart_DialogContent .lang-placeholder-to').attr('placeholder',(Skin.getInstance().get('MMMCart-lang-placeholder-to', 'To Email')));
		jQuery('#MMMCart_DialogContent .lang-placeholder-company').attr('placeholder',(Skin.getInstance().get('MMMCart-lang-placeholder-company', 'Your Company')));
		jQuery('#MMMCart_DialogContent .lang-placeholder-name').attr('placeholder',(Skin.getInstance().get('MMMCart-lang-placeholder-name', 'Your Name')));
		jQuery('#MMMCart_DialogContent .lang-placeholder-msg').attr('placeholder',(Skin.getInstance().get('MMMCart-lang-placeholder-msg', 'Message')));
	},

	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

// ****************************************************************************
// ****************************************************************************
// Constants used to register and identify custom PureMVC events
// ****************************************************************************
// ****************************************************************************