// ----------------------------------------------------------------------------
// This View handles the Template Component
// ----------------------------------------------------------------------------
RHImageWidget = new Class(
{
   Extends : WidgetView,
	
	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	

	_imageElement : null,
	_timerId : null,

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('RHImageWidget', this);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theWidgetData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init : function(theBasePath, theWidgetData)
    {		
		var theWidth = Number(theWidgetData.ContentWidth);
		var theHeight = Number(theWidgetData.ContentHeight);
		
		// Make sure the image widget will fit on the device...if not then scale proportionally until it will
		var theDeviceWidth = DeviceMgr.getInstance().getOrientationScreenWidth()*window.devicePixelRatio*0.95;
		var theDeviceHeight = DeviceMgr.getInstance().getOrientationScreenHeight()*window.devicePixelRatio*0.95;
		
		var theScaleTemp, theScale;
		theScale = theScaleTemp = 1.0;
		if (theDeviceWidth < theWidth)
		{
			theScaleTemp = theDeviceWidth/theWidth;
			theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
		}
		if (theDeviceHeight < theHeight)
		{
			theScaleTemp = theDeviceHeight/theHeight;
			theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
		}
		if (!Browser.Platform.desktop)
		{
			if (theDeviceHeight < theWidth)
			{
				theScaleTemp = theDeviceHeight/theWidth;
				theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
			}
			if (theDeviceWidth < theHeight)
			{
				theScaleTemp = theDeviceWidth/theHeight;
				theScale = (theScaleTemp < theScale) ? theScaleTemp : theScale;
			}
		}
		theWidth *= theScale;
		theHeight *= theScale;
		
		var theWidgetOptions = new Object(
		{
			basePath : theBasePath,
			title:  '',				// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			anchor: theWidgetData.Anchor,
			isClosable: ((theWidgetData.Anchor != 'top-banner') && (theWidgetData.Anchor != 'bottom-banner')),
			width:  theWidth,
			height: theHeight,
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});
		if (theWidgetData.onClose)
			theWidgetOptions.onClose = theWidgetData.onClose;
		this.parent(theWidgetData, theWidgetOptions);
	},

	// ------------------------------------------------------------------------
	// Put any code which needs to be executed when the widget is closed here
	// ------------------------------------------------------------------------
	onClose : function() 
	{
		if (this._timerId)
			clearInterval(this._timerId);
		this.parent();
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{		
		this.parent();
	/*	if (!Browser.Platform.desktop)
		{
			jQuery(".RHImageWidget").parent().css("background-color", "rgba(255,255,255,0.8)");
			jQuery(".RHImageWidget_Modal").hide();
		}
		else
			jQuery(".RHImageWidget_Modal").show();
	*/	if (this._data.Time == undefined)
		{
			this._imageElement = this._widgetRootElement.getElement('.RHImageWidget_Image');
			this._imageElement.addEvent('click', this._onClick.bind(this));
			this._imageElement.mooTouchAdd({'click':true});
			this._imageElement.addEvent('load', this._onImageContentLoaded.bind(this));
			this._closeElement = this._widgetRootElement.getElement('#RHImageWidget_close');
			this._closeElement.addEvent('click', this.onClose.bind(this));
			this._closeElement.mooTouchAdd({'click':true});
			
			this._baseImagePath = this._data.BasePath;
			var theUrl = this._data.Url;
			if (!theUrl)
				theUrl = this._data.url;
			this._setImage(this._imageElement, theUrl);
		}
		else
		{		
			this._imageElement = this._widgetRootElement.getElement('.RHImageWidget_Image');
			this._imageElement.addEvent('click', this._onClickRotate.bind(this));
			this._imageElement.mooTouchAdd({'click':true});

			this._baseImagePath = this._data.BasePath;
			
			this._imagesArray = this._data.Images;
			this._imagesArrayIndex = 0;
			this._setImage(this._imageElement, this._imagesArray[this._imagesArrayIndex].Url);
			this._imageElement.addEvent('load', this._onImageContentLoaded.bind(this));
			this._timerId = this._onRotate.periodical(this._data.Time, this);
		}
	},

	_onImageContentLoaded : function()
	{
		this._show();
	},
	
	// ------------------------------------------------------------------------
	// Timer event handler for the rotating the image 
	// ------------------------------------------------------------------------
	_onRotate : function ()
	{
		this._imagesArrayIndex++;
		if (this._imagesArrayIndex >= this._imagesArray.length)
			this._imagesArrayIndex = 0;
		this._setImage(this._imageElement, this._imagesArray[this._imagesArrayIndex].Url);
	},

	// ------------------------------------------------------------------------
	// Event handler for the click event on the image link
	// ------------------------------------------------------------------------
    _onClickRotate : function()
    {
		this._imagesArrayIndex++;
		if (this._imagesArrayIndex >= this._imagesArray.length)
			this._imagesArrayIndex = 0;
		var theLink = this._imagesArray[this._imagesArrayIndex].Link;
		if (!theLink)
			theLink = this._imagesArray[this._imagesArrayIndex].link;

		Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, {link:theLink, source:'Link'})
    },
    _onClick : function()
    {
		var theLink = this._data.Link;
		if (!theLink)
			theLink = this._data.link;

		Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, {link:theLink, source:'Link'})
    },	


	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});