// ----------------------------------------------------------------------------
// This View handles the Obsolete Cart
// ----------------------------------------------------------------------------
WhiteCapOrderForms = new Class(
{
	Extends : DialogView,
	
	// ************************************************************************
	// ************************************************************************
	//     LIST OF ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return false;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return true;},

	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function(){return [];},
	listCssAssets : function(){return [];},
	
	// ------------------------------------------------------------------------
	// This function returns a path to an optional html asset to load for this component
	// ------------------------------------------------------------------------
	listHtmlAsset : function(){return 'WhiteCapOrderForms.html';},

// ------------------------------------------------------------------------
	// This is a proxy for the UIMediator listNotificationInterests function.
	// 
	// This function returns the list of notifications to register this view for.
	//
	// @return {String[]} - the array of notification names to act upon.
	// ------------------------------------------------------------------------
    listNotificationInterests : function()
    {
		return	[
					WhiteCapOrderForms.ReloadActiveOrderItems,
					WhiteCapOrderForms.ShowOrderMax,
					WhiteCapOrderForms.ShowOrderMin,
					WhiteCapOrderForms.CloseAddToCart,
				];
    },

	// ------------------------------------------------------------------------
	// This is a proxy for the UIMediator handleNotification function.
	//
	// This function is called to handle all notifications listed in the 
	// listNotificationInterests function
	//
	// Arguments:
	//     notification (Notification) - The notification to act upon
	// ------------------------------------------------------------------------
    handleNotification : function(notification)
    {
		var theArgs = notification.getBody();
		switch(notification.getName())
		{
			// **************************************************
			// Event handling for managing Application and Dynamic Component Toolbars
			// **************************************************
			case WhiteCapOrderForms.ReloadActiveOrderItems:
				if (!this._data)
					this._updateOrderList();
				this._updateCount();
				break;
			case WhiteCapOrderForms.ShowOrderMax:
				this._popUpWindow.maximize();
				this._onMaximize();
				break;
			case WhiteCapOrderForms.ShowOrderMin:
				this._onRestore();
				break;
			case WhiteCapOrderForms.CloseAddToCart:
				if (this._data)
				{
					this._popUpWindow.close();	
				}
				break;
		}
    },
	// ************************************************************************
	// ************************************************************************
	//     MEMBERS VARIABLES
	// ************************************************************************
	// ************************************************************************	
	
	_appState : null,
	_orderItems : new Array(),
	_orders : new Array(),
	_orderNameArray : new Array(),

	// AddOrderPanel
	_addOrderPanel : null,
	_addOrderPanel_NameInput : null,
	_addOrderPanel_AddOrderBtn : null,
	_addOrderPanel_BackBtn : null,
	
	// OrderListPanel
	_orderListPanel_ListElement : null,
	
	// AddPanel
	_addPanel : null,
	_addPanel_OrderNameDropdown : null,
	_addPanel_CreateNewOrderBtn : null,
	_addPanel_AddContainer : null,
	_addPanel_AddBtn : null,			
		
	// EmailPanel	
	_emailPanel : null,
	_emailPanelToName : null,
	_emailPanelToEmail : null,
	_emailPanelToCompanyName : null,
	_emailPanelToZip : null,
	_emailPanelNotes : null,

	// SendPanel
	_sentPanel : null,
	
	// ListPanel
	_listPanel : null,
	_listPanel_EmptyMessage: null,

	// PlaceOrderPanel
	_placeOrderPanel : null,
	_placeOrderPanelElement : null,
	
	// Buttons
	_buttonContainer : null,
	_buttonActionCenter : null,
	_emailBtn : null,
	_printBtn : null,
	_orderBtn : null,
	_backBtn : null,
	_back_sentBtn : null,
	_back_orderBtn : null,
	_sendBtn : null,
	_send_orderBtn : null,
	_continueBtn : null,
	_clearallBtn : null,
	_editBtn : null,
	_doneBtn : null,
	_placeBtn : null,
	_shipMatchesBillingYRdoBtn : null,
	_shipMatchesBillingNRdoBtn : null,
	
	_length_warning : null,
	_change_order_container : null,
	_continue_container : null,
	_emailOrder_container : null,
	_send_container : null,
	_sendorder_container : null,
	_place_container : null,
	_incButton : null,
	_decButton : null,
	_qtyInput : null,
	_mooTouchScroller : null,
	_applicationViewElement : null,
	_dialogWidth : null,
	_dialogHeight : null,
	_fields : null,
	_activeOrder : null,
	_activeOrderFormName : null,
	_defaultPort : null,
	
	_minView_PortraitWidth : null,
	_minView_PortraitHeight : null,
	_minView_LandscapeWidth : null,
	_minView_LandscapeHeight : null,
	
	_orderView_PortraitWidth : null,
	_orderView_PortraitHeight : null,
	_orderView_LandscapeWidth : null,
	_orderView_LandscapeHeight : null,	
	
	_portraitWidth : null,
	_portraitHeight : null,
	_landscapeWidth : null,
	_landscapeHeight : null,
	
	_rootElement : null,
	_showMinMode : null,		
	
	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize : function()
	{
		this.parent('WhiteCapOrderForms', this);
	},
	
	// ------------------------------------------------------------------------
	// Call this function to see if this component can be init'ed.  The default
	// behavior is to enforce only one instance of this dialog open at a time.
	// ------------------------------------------------------------------------
	canInit : function(data)
	{
		if (data && data.Mode == 'min')
		{
			this._showMinMode = true;
			data = null;
		}
		var rtn = (!WhiteCapOrderForms.CartDialogActive || data);
		
		if (!rtn && WhiteCapOrderForms.CartDialogActive)
			Facade.getInstance().sendNotification(WhiteCapOrderForms.ShowOrderMax);
		
		return rtn;
	},

    init : function(theBasePath, theDialogData)
    {		
		if (this._showMinMode)
			theDialogData = null;
		//View Port Globals
		var viewportWidth = jQuery(window).width();
		var viewportHeight = jQuery(window).height();

		this._applicationViewElement = $('ApplicationView');
		var appSize = this._applicationViewElement.measure(function(){return this.getSize();});
		var appWidth = appSize.x;
		var appHeight = appSize.y;
		
		this._fields = 4;
		
		this._activeOrder = this._appState.get(AppState.activeOrder);
		if (this._activeOrder && this._activeOrder.orderName )
		{
			this._activeOrderFormName = this._activeOrder.orderName;
			this._orderItems = Preferences.getInstance().get('WhiteCapOrderForms'+this._activeOrder.orderNumber);
			if (!this._orderItems)
				this._orderItems = [];	
		}
		else
		{
			this._activeOrder = [];
			this._orderItems = [];
		}

		/***** RMG 01/15/2014 - Changed to use the DialogView portrait/landscape mechanism
		if (theDialogData)
		{
			_dialogWidth = 320;
			_dialogHeight = 200;
		}
		else
		{
			if (Browser.Platform.tablet) {
				_dialogHeight = viewportHeight - 54;
				_dialogWidth = viewportWidth - 4;
			}
			else if (appWidth < 1025) {
				_dialogWidth = viewportWidth - 4;
				_dialogHeight = viewportHeight - 37;
			}
			else {
				_dialogHeight = appHeight - 37;
				_dialogWidth = 960;	
			};
		}
		*****/
		//var portraitWidth, portraitHeight, landscapeWidth, landscapeHeight;
		if (DeviceMgr.getInstance().isOrientationPortrait())
		{
			this._portraitWidth = DeviceMgr.getInstance().getOrientationScreenWidth()*window.devicePixelRatio;
			this._portraitHeight = DeviceMgr.getInstance().getOrientationScreenHeight()*window.devicePixelRatio;
		}
		else
		{
			this._portraitWidth = DeviceMgr.getInstance().getOrientationScreenHeight()*window.devicePixelRatio;
			this._portraitHeight = DeviceMgr.getInstance().getOrientationScreenWidth()*window.devicePixelRatio;
		}
		this._landscapeWidth = this._portraitHeight;
		this._landscapeHeight = this._portraitWidth;

		if ((theDialogData) && (!Browser.Platform.mobile))
		{
			// Add to Cart dialog size
			this._portraitWidth = 450;
			this._portraitHeight = 325;
			this._landscapeWidth = 450;
			this._landscapeHeight = 325;
		}
		else if (Browser.Platform.desktop)
		{
			// Cart dialog size for desktop
			this._portraitWidth = 700;
			this._portraitHeight = appHeight - 37 - 49;
			this._landscapeWidth = this._portraitWidth;
			this._landscapeHeight = this._portraitHeight;
			
			this._minView_PortraitWidth = 400;
			this._minView_PortraitHeight = (appHeight/2) - 37 - 49;
			this._minView_LandscapeWidth = this._minView_PortraitWidth;
			this._minView_landscapeHeight = this._minView_PortraitHeight;
		}
		else if (!Browser.Platform.mobile)
		{
			this._portraitWidth = 600;
			this._portraitHeight = appHeight - 37 - 49;
			this._landscapeWidth = this._portraitWidth;
			this._landscapeHeight = this._portraitHeight;
			
			this._minView_PortraitWidth = 400;
			this._minView_PortraitHeight = (appHeight/2) - 37 - 49;
			this._minView_LandscapeWidth = this._minView_PortraitWidth;
			this._minView_landscapeHeight = this._minView_PortraitHeight;	
		}
		else
		{
			this._portraitWidth = '100%';
			this._portraitHeight = appHeight - 37 - 49;
			this._landscapeWidth = this._portraitWidth;
			this._landscapeHeight = this._portraitHeight;
			
			this._minView_PortraitWidth = '100%';
			this._minView_PortraitHeight = (appHeight/2) - 37 - 49;
			this._minView_LandscapeWidth = this._minView_PortraitWidth;
			this._minView_landscapeHeight = this._minView_PortraitHeight;	
		}
		
		this.parent(theDialogData,
		{
			basePath:           theBasePath,
			title:              Skin.getInstance().get('WhiteCapOrderFormsDialogTitle', 'List'),
			// RMG 01/15/2014 - Changed to use the DialogView portrait/landscape mechanism
			//width:              _dialogWidth,
			//height:				_dialogHeight,
			width: this._minView_PortraitWidth,
			height: this._minView_PortraitHeight,
			left: undefined,
			top: undefined,
			isDraggable:		true,
			hasFooter:          false,
			isModal: 			theDialogData,
			isMaximizable:		true,
			maximizeSize: {x:this._portraitWidth, y:this._portraitHeight},
			isResizable:		true,
			resizeLimits:		
			{
				x : [278, 278],
				y : [300, 9999]
			},
			_ie_comma_safety : 0	// Keep as last option (doesn't have trailing comma)
		});	
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded : function()
	{	
		this.parent();
		this._popUpWindow.setTitle(Skin.getInstance().get('WhiteCapOrderFormsDialogTitle', 'List'));
				
		this._emailPanel = this._widgetRootElement.getElement('#WhiteCapOrderForms_EmailPanel');
		this._sentPanel = this._widgetRootElement.getElement('#WhiteCapOrderForms_SentPanel');
		this._listPanel = this._widgetRootElement.getElement('#WhiteCapOrderForms_ListPanel');
		this._listPanel_EmptyMessage = this._widgetRootElement.getElement('#WhiteCapOrderForms_ListPanel_Empty');		
		this._placeOrderPanel = this._widgetRootElement.getElement('#WhiteCapOrderForms_PlaceOrderPanel');
		this._addPanel = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel');
		this._addPanel_AddBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_AddBtn');		
		this._addPanel_AddContainer = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_AddContainer');
		this._addPanel_OrderNameDropdown = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_OrderNameDropdown');
		this._addPanel_CreateNewOrderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_CreateNewOrderBtn');		
		this._addOrderPanel = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddOrderPanel');
		this._addOrderPanel_BackBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddOrderPanel_BackBtn');
		this._addOrderPanel_AddOrderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddOrderPanel_AddOrderBtn');
		this._addOrderPanel_NameInput = this._widgetRootElement.getElement('#WhiteCapOrderForms_AddOrderPanel_Name');
		
		this._buttonContainer = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_container');
		this._buttonActionCenter = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_container .actionCenter');
		this._emailBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_email');
		this._memailBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_memail');
		this._printBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_print');		
		this._orderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_order');
		this._backBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_back');
		this._back_sentBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_back_sent');
		this._back_orderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_back_order');
		this._sendBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_send');
		this._send_orderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_sendorder');
		this._placeBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_place');
		this._continueBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_continue');
		this._changeOrderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_change_order');
		this._mchangeOrderBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_change_morder');
		this._clearallBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_clearall');
		this._mclearallBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_mclearall');
		this._editBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_edit');
		this._doneBtn = this._widgetRootElement.getElement('#WhiteCapOrderForms_button_done');
		this._shipMatchesBillingYRdoBtn = this._widgetRootElement.getElement('#shipmatchesbill1');
		this._shipMatchesBillingNRdoBtn = this._widgetRootElement.getElement('#shipmatchesbill2');
		this._change_order_container = this._widgetRootElement.getElement('#WhiteCapOrderForms_change_order_container');
		this._length_warning = this._widgetRootElement.getElement('#WhiteCapOrderForms_length_warning');
		this._continue_container = this._widgetRootElement.getElement('#WhiteCapOrderForms_continue_container');
		this._emailOrder_container = this._widgetRootElement.getElement('#WhiteCapOrderForms_emailOrder_container');
		this._send_container = this._widgetRootElement.getElement('#WhiteCapOrderForms_send_container');
		this._sendorder_container = this._widgetRootElement.getElement('#WhiteCapOrderForms_sendorder_container');
		this._place_container = this._widgetRootElement.getElement('#WhiteCapOrderForms_place_container');
		this._qtyInput = this._widgetRootElement.getElement('#WhiteCapOrderForms_quantity');
		this._incButton = this._widgetRootElement.getElement('#WhiteCapOrderForms_increment');
		this._decButton = this._widgetRootElement.getElement('#WhiteCapOrderForms_decrement');				
		

		// ********** Add event handlers (don't forget mooTouchAdd) **********
		this._addPanel_AddBtn.addEvent('click', this._onClickAdd.bind(this));
		this._addPanel_OrderNameDropdown.addEvent('change', this._onOrderDropdownSelect.bind(this));
		this._addPanel_CreateNewOrderBtn.addEvent('click', this._onCreateNewOrder.bind(this));
		this._addOrderPanel_BackBtn.addEvent('click', this._onClickBackToOrder.bind(this));		
		this._addOrderPanel_AddOrderBtn.addEvent('click', this._onCreateNewOrder.bind(this));
		this._addOrderPanel_NameInput.addEvent('keydown', this._onOrderFormNameInputKeydown.bind(this));
//		this._emailBtn.addEvent('click', this._onClickEmail.bind(this));
		this._memailBtn.addEvent('click', this._onClickOrder.bind(this));
		this._printBtn.addEvent('click', this._onClickPrint.bind(this));		
		this._orderBtn.addEvent('click', this._onClickOrder.bind(this));
		this._backBtn.addEvent('click', this._onClickBack.bind(this));
		this._back_sentBtn.addEvent('click', this._onClickBack.bind(this));
		this._back_orderBtn.addEvent('click', this._onClickBack.bind(this));
		this._sendBtn.addEvent('click', this._onClickSend.bind(this));
		this._send_orderBtn.addEvent('click', this._onClickSendOrder.bind(this));
		this._continueBtn.addEvent('click', this._onContinue.bind(this));
		this._changeOrderBtn.addEvent('click', this._showSelectOrder.bind(this));
		this._mchangeOrderBtn.addEvent('click', this._showSelectOrder.bind(this));
		this._clearallBtn.addEvent('click', this._onClearAll.bind(this));
		this._mclearallBtn.addEvent('click', this._onClearAll.bind(this));
		this._shipMatchesBillingYRdoBtn.addEvent('click', this._onShipMatchesBilling.bind(this));
		this._shipMatchesBillingNRdoBtn.addEvent('click', this._onShipDoesntMatchBilling.bind(this));
		
		this._incButton.addEvent('click',this._onIncrementBtn.bind(this));
		this._decButton.addEvent('click',this._onDecrementBtn.bind(this));
		this._incButton.mooTouchAdd({'click':true});
		this._decButton.mooTouchAdd({'click':true});
//		this._addPanel_OrderNameDropdown.mooTouchAdd({'click':true});
		this._addPanel_AddBtn.mooTouchAdd({'click':true});
		this._addPanel_CreateNewOrderBtn.mooTouchAdd({'click':true});		
		this._addOrderPanel_AddOrderBtn.mooTouchAdd({'click':true});
		this._emailBtn.mooTouchAdd({'click':true});
		this._memailBtn.mooTouchAdd({'click':true});
		this._printBtn.mooTouchAdd({'click':true});
		this._orderBtn.mooTouchAdd({'click':true});
		this._placeBtn.mooTouchAdd({'click':true});
		this._backBtn.mooTouchAdd({'click':true});
		this._back_sentBtn.mooTouchAdd({'click':true});
		this._back_orderBtn.mooTouchAdd({'click':true});
		this._sendBtn.mooTouchAdd({'click':true});
		this._send_orderBtn.mooTouchAdd({'click':true});
		this._continueBtn.mooTouchAdd({'click':true});
		this._changeOrderBtn.mooTouchAdd({'click':true});
		this._mchangeOrderBtn.mooTouchAdd({'click':true});
		this._clearallBtn.mooTouchAdd({'click':true});
		this._mclearallBtn.mooTouchAdd({'click':true});
		this._editBtn.mooTouchAdd({'click':true});
		this._doneBtn.mooTouchAdd({'click':true});
		this._shipMatchesBillingYRdoBtn.mooTouchAdd({'click':true});
		this._shipMatchesBillingNRdoBtn.mooTouchAdd({'click':true});
		
		this._popUpWindow.windowDiv.maximizeIcon.addEvent(SpriteButton.CLICK, this._onMaximize.bind(this));
		this._popUpWindow.windowDiv.restoreIcon.addEvent(SpriteButton.CLICK, this._onRestore.bind(this));

		this._setStyleForLangResource(this._emailBtn,   'background-image', 'WhiteCapOrderFormsEmailBtnPath');
		this._setStyleForLangResource(this._memailBtn,   'background-image', 'WhiteCapOrderFormsEmailBtnPath');
		this._setStyleForLangResource(this._printBtn,   'background-image', 'WhiteCapOrderFormsPrintBtnPath');
		this._setStyleForLangResource(this._orderBtn,   'background-image', 'WhiteCapOrderFormsOrderBtnPath');
		this._setStyleForLangResource(this._placeBtn,   'background-image', 'WhiteCapOrderFormsPlaceBtnPath');
		this._setStyleForLangResource(this._backBtn,    'background-image', 'WhiteCapOrderFormsBackBtnPath');
		this._setStyleForLangResource(this._back_sentBtn,    'background-image', 'WhiteCapOrderFormsBackBtnPath');
		this._setStyleForLangResource(this._back_orderBtn,    'background-image', 'WhiteCapOrderFormsBackBtnPath');
		this._setStyleForLangResource(this._sendBtn,    'background-image', 'WhiteCapOrderFormsSendBtnPath');
		this._setStyleForLangResource(this._send_orderBtn,    'background-image', 'WhiteCapOrderFormsSendBtnPath');
		this._setStyleForLangResource(this._addPanel_AddBtn,     'background-image', 'WhiteCapOrderFormsAddPanelAddBtnPath');
		this._setStyleForLangResource(this._addOrderPanel_AddOrderBtn,     'background-image', 'WhiteCapOrderFormsAddOrderPanelAddBtnPath');
		this._setStyleForLangResource(this._continueBtn,'background-image', 'WhiteCapOrderFormsContinueBtnPath');
		this._setStyleForLangResource(this._changeOrderBtn,'background-image', 'WhiteCapOrderFormsContinueBtnPath');
		this._setStyleForLangResource(this._clearallBtn,'background-image', 'WhiteCapOrderFormsClearAllBtnPath');
		this._setStyleForLangResource(this._mclearallBtn,'background-image', 'WhiteCapOrderFormsClearAllBtnPath');
		this._setStyleForLangResource(this._editBtn,    'background-image', 'WhiteCapOrderFormsEditBtnPath');
		this._setStyleForLangResource(this._doneBtn,    'background-image', 'WhiteCapOrderFormsDoneBtnPath');
		this._setStyleForLangResource(this._addPanel_CreateNewOrderBtn,'background-image', 'WhiteCapOrderFormsAddPanelAddBtnPath');
				
		this._orders = Preferences.getInstance().get('WhiteCapOrderFormsOrders');
		if (this._orders === undefined)
			this._orders = [];

		jQuery('.WhiteCapOrderForms_AddPanel_qty').on('keypress', function(ev) 
		{
			var keyCode = window.event ? ev.keyCode : ev.which;
			//codes for 0-9
			if (keyCode < 48 || keyCode > 57) 
			{
			//codes for backspace, delete, enter
				if (keyCode != 0 && keyCode != 8 && !ev.ctrlKey) 
				{
					ev.preventDefault();
				}
			}
		});
		jQuery(".WhiteCapOrderForms_AddPanel_unitlength").keydown(function(e){
			var key = e.which;

			// backspace, tab, left arrow, up arrow, right arrow, down arrow, delete, numpad decimal pt, period, enter
			if (key != 8 && key != 37 && key != 38 && key != 39 && key != 40 && key != 46 && key != 110 && key != 190 && key != 13){
				if (key < 48){
					e.preventDefault();
				}
				else if (key > 57 && key < 96){
					e.preventDefault();
				}
				else if (key > 105) {
					e.preventDefault();
				}
			}
		});

		this._qtyInput.maxLength = 4;
		this._buttonContainer.show();
		this._show();
		if (this._data)
			this._showAddToCart();
		else if (!this._activeOrderFormName)	
			this._showSelectOrder();
		else if (this._showMinMode)
		{
			//this._showOrderMin();
			this._showOrderMax();
			this._onRestore();
		}
		else
			this._showOrderMax();
		
		// Dialog had to be visible before we arrange footer dialog buttons
		this._doButtonContainerLayout();
	},

	// ------------------------------------------------------------------------
	// Put any code which needs to be executed when the dialog is closed here
	// ------------------------------------------------------------------------
	onClose : function()
	{
		if (!this._data)
			WhiteCapOrderForms.CartDialogActive = false;	
		
		Preferences.getInstance().flush();
		//Facade.getInstance().sendNotification.delay(1,Facade.getInstance(),[WhiteCapOrderForms.ReloadActiveOrderItems]);
		Facade.getInstance().sendNotification(WhiteCapOrderForms.ReloadActiveOrderItems);
		PopUpWindow.hideModalOverlay();
		this.parent();
	},
	
	_onCancel : function()
	{
		this._popUpWindow.close();
	},

	_onContinue : function()
	{
		this._popUpWindow.close();
	},
	
	// ************************************************************************
	// ************************************************************************
	//
	// ************* Add Custom Functions and Event Handlers here *************
	//
	// ************************************************************************
	// ************************************************************************
	_onMaximize : function(e)
	{
		this._rootElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_DialogContent');
		if (this._rootElement && this._rootElement.hasClass('minimized'))
		{
			this._rootElement.removeClass('minimized');
			this._showOrderMax();
			if (this._activeOrderFormName)
			{
				var windowTitle = this._activeOrderFormName;
				this._popUpWindow.setTitle(windowTitle);				
			}
			else
			{
				this._popUpWindow.setTitle('');	
			}
			
			PopUpWindow.showModalOverlay.delay(1,this);	
		}
		Facade.getInstance().sendNotification(WhiteCapOrderForms.CloseAddToCart);
		
		
	},
	
	_onRestore : function(e)
	{
		this._rootElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_DialogContent');
		this._listElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_ListPanel_theList');
		this._rootElement.erase('class').addClass('minimized');
		this._showOrderMin();
	},
	
	
	_remItem : function(e)
	{
		var theItem = e.target;
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		var theLineId = 'WhiteCapOrderForms_ListPanel_itemwrapper_'+theItemId;
		this._listElement = $(theLineId);
		var theItemWrapper = this._listElement.getElementById(theButtonId);
		theItemWrapper.destroy();
		this._orderItems.splice(theItemId, 1);
		//Facade.getInstance().sendNotification.delay(1,Facade.getInstance(),[WhiteCapOrderForms.ReloadActiveOrderItems]);
		Facade.getInstance().sendNotification(WhiteCapOrderForms.ReloadActiveOrderItems);
		this._displayItems();
		this._keepEditState();
		if (this._orderItems.length == 0)
			this._orderBtn.hide();
	},
	
	_remOrder : function(e)
	{
		var theOrder = e.target;
		var theButtonId = theOrder.get('id');
		var theOrderId = theButtonId.substr(0,theButtonId.lastIndexOf('_'));
		var theLineId = 'WhiteCapOrderForms_Order_wrapper_'+theOrderId;
		var theOrderWrapper = this._widgetRootElement.getElementById(theLineId);
		theOrderWrapper.destroy();
		// Remove order from orders
		for (var i=0;i<this._orders.length;i++)
		{
			var curOrderNum = this._orders[i].orderNumber;
			if (curOrderNum == theOrderId)
			{
				this._orders.splice(i,1);
				break;
			}
		}
		Preferences.getInstance().set('WhiteCapOrderFormsOrders', this._orders);
		// Remove the order
		Preferences.getInstance().set('WhiteCapOrderForms'+theOrderId,null);
		// Check to see if order removed was active order
		if (this._activeOrder && this._activeOrder.orderName)
		{
			if (theOrderId == this._activeOrder.orderNumber)
			{
				this._onChangeActiveOrder(null, null);
			}		
		}
	},	
	
	_onPageClick : function(event)
	{
		event.preventDefault();
		var theItemLink = event.target.get('href');
		//this._popUpWindow.close();
		Facade.getInstance().sendNotification(ApplicationFacade.GOTO_URL, {link:theItemLink});
	},

	_filterOrders : function(e)
	{
		var orderFormName = this._widgetRootElement.getElementById('WhiteCapOrderForms_AddOrderPanel_Name').value;
		var ordersText = '';
		orderNameArray = new Array();
		orderItemArray = new Array();
		for (var i=this._orders.length-1;i>=0;i--)
		{
			var curOrderNum = this._orders[i].orderNumber;
			var currentOrderFormName = this._orders[i].orderName;
			if (currentOrderFormName.toUpperCase().indexOf(orderFormName.toUpperCase()) == 0)
			{
				ordersText += '<div id=\"WhiteCapOrderForms_Order_wrapper_' + curOrderNum + '\" class=\"WhiteCapOrderForms_Order\">';
				ordersText += '		<div class=\"WhiteCapOrderForms_AddPanel_Title ten mobile-eight columns\">' + currentOrderFormName + '</div>';
				ordersText += '		<div class=\"WhiteCapOrderForms_ListPanel_delete two columns\">';
				ordersText += '			<div id=\"' + curOrderNum + '_rmv\" class=\"WhiteCapOrderForms_OrderListPanel_remove glyphicon glyphicon-ban-circle\"></div>';
				ordersText += '		</div>';
				ordersText += '</div>';	
			}		
		}	    
		this._orderListPanel_ListElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_OrderListPanel_theList');
	    this._orderListPanel_ListElement.set('html', ordersText);
	    
		var theElementList;

		//Loop through remove events
		theElementList = this._orderListPanel_ListElement.getElements('.WhiteCapOrderForms_OrderListPanel_remove');
		theElementList.each(function(order, index)
		{
			order.addEvent('click', this._remOrder.bind(this));
			order.mooTouchAdd({'click':true});
		}.bind(this));
		
		theElementList = this._orderListPanel_ListElement.getElements('.WhiteCapOrderForms_Order');
		theElementList.each(function(order, index)
		{
			order.addEvent('click', this._onSetActiveOrder.bind(this));
			order.mooTouchAdd({'click':true});
		}.bind(this));	
	},
	
	_onClickAddOrder : function(e)
	{
		var orderFormName = this._widgetRootElement.getElementById('WhiteCapOrderForms_AddOrderPanel_Name').value;
		if (orderFormName == '')
		{
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:'Please enter a valid list name.', title:'Invalid List Name'});
			return;
		}
		var order_cnt = this._orders.length;
		// find next available order number
		//var orderNum = "Order_0000";
		var orderNum = "Order0";
		var orderNameExists = false;
		for (var i=0;i<order_cnt;i++)
		{
			var orderName = this._orders[i].orderName;
			if (orderName.toUpperCase() == orderFormName.toUpperCase())
			{
				orderNameExists = true;
				orderNum = this._orders[i].orderNumber;
				break;
			}
			if (orderNameExists)
				break;
		}
		
		if (!orderNameExists)
		{
			for (var i=0;i<10000;i++)
			{
				if (i>order_cnt)
					break;
				// pad the number to four digits
				///var padOrderNum= "0000" + i;
				var foundMatch = false;
				///orderNum = "Order_" + padOrderNum.slice(-4);
				orderNum = "Order" + i;
				for (var n=0;n<order_cnt;n++)
				{
					var orderNumber = this._orders[n].orderNumber;
					if (orderNumber == orderNum)
					{
						// we found an open slot so 	
						foundMatch = true;
						break;
					}
				}
				if (!foundMatch)
					break;
			}
			this._orders.push({orderNumber:orderNum,orderName:orderFormName});
			Preferences.getInstance().set('WhiteCapOrderFormsOrders', this._orders);
			this._orderItems = [];
			//Facade.getInstance().sendNotification.delay(1,Facade.getInstance(),[WhiteCapOrderForms.ReloadActiveOrderItems]);
			Facade.getInstance().sendNotification(WhiteCapOrderForms.ReloadActiveOrderItems);
		}
		else
		{
			var msg = Skin.getInstance().get('WhiteCapOrderFormsOrderExistsMsg','This list name already exists.  Would you like to switch to this list?');
			var title = Skin.getInstance().get('WhiteCapOrderFormsOrderExistsTitle','List Name Exists');
			var y = Skin.getInstance().get('YesButton', 'Yes');
			var n = Skin.getInstance().get('NoButton', 'No');			
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_CONFIRM, {message:msg, title:title, leftbutton:y, rightbutton:n, callback:function(result)
			{
				if (result == true)
				{
					var ordersText = '';
					ordersText += '<div class=\"WhiteCapOrderForms_Order\">';
					ordersText += '		<div class=\"WhiteCapOrderForms_AddPanel_Title ten columns\">' + orderNum + '</div>';
					ordersText += '		<div class=\"WhiteCapOrderForms_ListPanel_delete two columns\">';
					ordersText += '			<div id=\"' + orderNum + '\" class=\"WhiteCapOrderForms_OrderListPanel_remove glyphicon glyphicon-ban-circle\"></div>';
					ordersText += '		</div>';
					ordersText += '</div>';
					
					this._onChangeActiveOrder(orderFormName, orderNum);
				}
				else
					this._widgetRootElement.getElementById('WhiteCapOrderForms_AddOrderPanel_Name').value = '';
			}.bind(this)});
			return;	
		}									
		
		this._onChangeActiveOrder(orderFormName, orderNum);
		this._selectAddOrder();
	},
	
	_onClickAdd : function(e)
	{
		if (!this._data)
			return;
			
		if (!this._activeOrderFormName)
		{
			var msg = Skin.getInstance().get('WhiteCapOrderFormsNoActiveOrderMsg','No list is currently selected.  Please select an existing list click \"New List\" to create a new list.');
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:msg, title:''});
			return false;
		}
			
		this._emailElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_fields');
		var element = this._emailElement.getElementById('WhiteCapOrderForms_quantity');
		var qty = element.value;

		var theBook = this._appState.get(currentBook);
		var theBookList = this._appState.get(currentBookList);
		var theBookIndex = theBookList.getBookListIndex(theBook.bookCode);
		var theBookListEntry = theBookList.getBookListEntry(theBookIndex);
		var theBookPageIndex = this._appState.get(currentBookPageDest).BookPageIndex;
		var theBookTitle =  theBookListEntry.title;
		var theBookCover = theBookListEntry.thumbnailBig;
		var theBookCoverUrl = theBookListEntry.getBookFolder(false) + theBookListEntry.thumbnailBig;
		var title,model,price,desc,bookcode,pagelabel,booktitle;

		sku = this._data.find('sku').text();
		desc = this._data.find('desc').text();
		price = this._data.find('price').text();
		bookcode = theBook.bookCode;
		booktitle = theBookTitle;
		bookcover = theBookCoverUrl;
		pagelabel = theBook.getPageLabel(theBookPageIndex);

		var notInList = true;
		for (var i = 0; i < this._orderItems.length; i++)
		{
			if ( (this._orderItems[i].sku == sku) && (this._orderItems[i].desc == desc))
			{
				qty = (this._orderItems[i].qty.toInt() + qty.toInt()).toString();
				this._orderItems[i].qty = qty;
				Preferences.getInstance().set('WhiteCapOrderForms'+this._activeOrder.orderNumber, this._orderItems);
				notInList = false;
				break;
			}
		}
		if (notInList)
		{
			this._orderItems.push({sku:sku, desc:desc, qty:qty, bookcode:bookcode, booktitle:booktitle, bookcover:bookcover, pagelabel:pagelabel, price:price});
			Preferences.getInstance().set('WhiteCapOrderForms'+this._activeOrder.orderNumber, this._orderItems);
		}
		//Facade.getInstance().sendNotification(WhiteCapOrderForms.ReloadActiveOrderItems);
		
		this._addPanel_AddContainer.show();
		this._change_order_container.hide();
		this._continue_container.hide();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._place_container.hide();

		this._emailBtn.hide();
		this._memailBtn.hide();
		this._printBtn.hide();
		this._orderBtn.hide();
		this._placeBtn.hide();
	//	if (!WhiteCapOrderForms.CartDialogActive)
		if ((!WhiteCapOrderForms.CartDialogActive) && (!Browser.Platform.mobile))
			Facade.getInstance().sendNotification(ApplicationFacade.LOAD_COMPONENT, {Name:'WhiteCapOrderForms', HasCss:true, Data:{Mode:'min'}});
		else if (!WhiteCapOrderForms.CartDialogActive)
			Facade.getInstance().sendNotification(ApplicationFacade.LOAD_COMPONENT, {Name:'WhiteCapOrderForms', HasCss:true});
		
			this._popUpWindow.close();
	
	},
	
	_changeQty : function(e)
	{
		var theItem = e.target;
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		var theLineId = 'WhiteCapOrderForms_ListPanel_itemwrapper_'+theItemId;
		this._listElement = $(theLineId);
		//WhiteCapOrderForms_ListPanel_qty_1
		var theItemWrapper = this._listElement.getElementById(theButtonId);
		var newQty = theItemWrapper.value;
		this._orderItems[theItemId].qty = newQty;
	},
	
	_changeUL : function(e)
	{
		var theItem = e.target;
		var unitlength = theElementListUL.value
		var theButtonId = theItem.get('id');
		var theItemId = theButtonId.substr(theButtonId.lastIndexOf('_')+1);
		var theLineId = 'WhiteCapOrderForms_ListPanel_itemwrapper_'+theItemId;
		this._listElement = $(theLineId);
		//WhiteCapOrderForms_ListPanel_qty_1
		var theItemWrapper = this._listElement.getElementById(theButtonId);
		var newQty = theItemWrapper.value;
		this._orderItems[theItemId].unitlength = newQty;
	},	
	
	_updateCount : function()
	{
		var cnt = this._orderItems.length;
		this._appState.set(cartListCnt, cnt);
		
		this._orderItems.sort(this._sortByDescription);
		Preferences.getInstance().flush(); // rems and adds weren't getting updated if user left dialog without closing it
		this._placeBtn.hide();
		
		// Hide/show/the empty cart image
		if (this._orderItems.length == 0)
		{
			this._listPanel.addClass('WhiteCapOrderForms_EmptyCart');
			this._emailBtn.hide();
			this._memailBtn.hide();
			this._printBtn.hide();
			this._orderBtn.hide();
			this._clearallBtn.hide();
			this._mclearallBtn.hide();
			this._editBtn.hide();
			this._doneBtn.hide();
			this._listPanel_EmptyMessage.show();

		}
		else
		{
			this._listPanel.removeClass('WhiteCapOrderForms_EmptyCart');
			this._emailBtn.show();
			this._memailBtn.show();
			this._printBtn.hide();
			this._clearallBtn.show();
			this._mclearallBtn.show();
			this._editBtn.show();
			this._listPanel_EmptyMessage.hide();

			if ((Browser.Platform.tablet) || (Browser.Platform.mobile) || (this._orderItems.length == 0)) 
			{ 
				this._orderBtn.hide();
			}
		}
		this._doButtonContainerLayout();
	},
	
	// ------------------------------------------------------------------------
	// This is an array sort helper function which will sort an array of records
	// in ascending order by description name
	// ------------------------------------------------------------------------
	_sortByDescription : function(a, b)
	{
		if (a.description == b.description) return 0;
		if (a.description > b.description) return 1;
		return -1;
	},
	
	_displayItems : function()
	{
		this._listElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_ListPanel_theList');
		if (!this._listElement)
			return;
		var itemsText = '';
		
		this._orderItems.sort(this._sortByDescription);

		var cart_currency = Skin.getInstance().get('CartCurrency', '$');
		
		for (var i = 0; i < this._orderItems.length; i++)
		{
			itemsText += '<div id=\"WhiteCapOrderForms_ListPanel_itemwrapper_'+i+'\" class=\"WhiteCapOrderForms_ListPanel_item row\">';
			
			itemsText += '	<div class=\"WhiteCapOrderForms_ListPanel_crosslinkcolumn one columns\">';
			itemsText += '		<div id=\"WhiteCapOrderForms_ListPanel_'+i+'_wrapper\" class=\"WhiteCapOrderForms_ListPanel_cover_wrapper four columns\">'
			itemsText += '		<img class=\"WhiteCapOrderForms_ListPanel_cover\" src=\"'+this._orderItems[i].bookcover+'\" />';
			itemsText += '		<a id=\"WhiteCapOrderForms_ListPanel_coverLink_'+i+'\" class="WhiteCapOrderForms_ListPanel_coverLink" href=\"app:BookCode='+this._orderItems[i].bookcode+'&PageLabel='+this._orderItems[i].pagelabel+'\"></a>';
			itemsText += '		</div>'
			itemsText += '		<a id=\"WhiteCapOrderForms_ListPanel_booktitle_'+i+'\" class=\"WhiteCapOrderForms_ListPanel_booktitle eight columns\" href=\"app:BookCode='+this._orderItems[i].bookcode+'&PageLabel='+this._orderItems[i].pagelabel+'\"">'+this._orderItems[i].booktitle+'</a>';
			itemsText += '		<div id=\"WhiteCapOrderForms_ListPanel_page_'+i+'_wrapper\" class=\"WhiteCapOrderForms_ListPanel_page_wrapper twelve columns\">' + this._orderItems[i].pagelabel;
			itemsText += '		</div>';
			itemsText += '	</div>'
			
			itemsText += '	<div class=\"WhiteCapOrderForms_ListPanel_detailscolumn five columns\">';
			itemsText += '		<div id=\"WhiteCapOrderForms_ListPanel_sku_'+i+'_wrapper\" class=\"WhiteCapOrderForms_ListPanel_sku_wrapper twelve columns\">';
			itemsText += '			<a id=\"WhiteCapOrderForms_ListPanel_sku_'+i+'\" class=\"WhiteCapOrderForms_ListPanel_sku\" href=\"app:Search=&#34;'+this._orderItems[i].sku+'&#34;\">'+this._orderItems[i].sku+'</a>';
			itemsText += '		</div>';
			
						
			itemsText += '		<div class=\"WhiteCapOrderForms_ListPanel_description twelve columns\">'+this._orderItems[i].desc+'</div>';
			itemsText += '			<a id=\"WhiteCapOrderForms_ListPanel_page_'+i+'\" class=\"WhiteCapOrderForms_ListPanel_page mobileshow\" href=\"app:BookCode='+this._orderItems[i].bookcode+'&PageLabel='+this._orderItems[i].pagelabel+'\">Page: '+this._orderItems[i].pagelabel+'</a>';			
			itemsText += '	</div>';
			
			itemsText += '	<div class=\"four columns\">';
			itemsText += '		<div class=\"mobilenumbers eight columns fullwidthmobile\">';
			itemsText += '			<div id=\"WhiteCapOrderForms_ListPanel_priceLabel\" class=\"three columns\">Price</div><div class=\"WhiteCapOrderForms_ListPanel_price twelve columns\">'+this._orderItems[i].price+'</div>';
			itemsText += '		</div>';
			itemsText += '		<input type=\"text\" value=\"'+this._orderItems[i].qty+'\" id=\"WhiteCapOrderForms_ListPanel_qty_'+i+'\" maxlength="4" name=\"qty\" onclick=\"this.focus();this.select()\" class=\"WhiteCapOrderForms_ListPanel_qty four columns form-control\"/>';			
			itemsText += '	</div>';

			itemsText += '	<div class=\"WhiteCapOrderForms_ListPanel_delete two columns\">';
			itemsText += '		<div id="cart_item_'+i+'" class=\"WhiteCapOrderForms_ListPanel_remove glyphicon glyphicon-ban-circle\"></div>';
			itemsText += '	</div>';
			itemsText += '</div>';
		}
		
	    this._listElement.set('html', itemsText);
	   // this._doFormSelect(this._listElement); // line not found in live cart source
	   	var theElementList;

		//Loop through remove events
		theElementList = this._listElement.getElements('.WhiteCapOrderForms_ListPanel_remove');
		theElementList.each(function(item, index)
		{
			item.addEvent('click', this._remItem.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));

		//Loop through page link events
		theElementList = this._listElement.getElements('.WhiteCapOrderForms_ListPanel_coverLink, .WhiteCapOrderForms_ListPanel_sku, .WhiteCapOrderForms_ListPanel_booktitle');
		theElementList.each(function(item, index)
		{
			item.addEvent('click', this._onPageClick.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));

		//Loop through quantity events
		theElementList = this._listElement.getElements('.WhiteCapOrderForms_ListPanel_qty');
		theElementList.each(function(item, index)
		{
			item.addEvent('change', this._changeQty.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));
		
		//Loop through quantity events
		theElementListUL = this._listElement.getElements('.WhiteCapOrderForms_ListPanel_unitlength');
		theElementListUL.each(function(item, index)
		{
			item.addEvent('change', this._changeUL.bind(this));
			item.mooTouchAdd({'click':true});
		}.bind(this));		

		this._listPanel.show();
		var scrollHeight = 0;
		if ((this._itemAdded != "") && (this._itemAdded != null))
		{
			for (var i = 0; i < this._orderItems.length; i++)
			{
				if (this._itemAdded == this._orderItems[i].recipe)
				{
					//this._mooTouchScroller.scrollTo(0,scrollHeight);
					this._itemAdded = "";
				}
				scrollHeight += this._listElement.getElementById('WhiteCapOrderForms_ListPanel_itemwrapper_'+i).offsetHeight;
			}
		}
			
		for (var i = 0; i < this._orderItems.length; i++)
		{	
			var test = jQuery('#WhiteCapOrderForms_ListPanel_unitlength_'+i+'').val();
			if ((Browser.Platform.mobile) && (jQuery('#WhiteCapOrderForms_ListPanel_unitlength_'+i+'').val() == 'N/A'))
			{
				jQuery('#WhiteCapOrderForms_ListPanel_unitlength_'+i+'').attr("style","display : none");
				jQuery('.mobile_'+i+'').attr("style","display : none !important");
			}
			else if (jQuery('#WhiteCapOrderForms_ListPanel_unitlength_'+i+'').val() == 'N/A')
			{
				jQuery('#WhiteCapOrderForms_ListPanel_unitlength_'+i+'').attr("style","visibility : hidden");
				jQuery('.mobile_'+i+'').attr("style","display : none");
			}
		}
		jQuery('.WhiteCapOrderForms_ListPanel_qty').on('keypress', function(ev) 
		{
			var keyCode = window.event ? ev.keyCode : ev.which;
			//codes for 0-9
			if (keyCode < 48 || keyCode > 57) 
			{
			//codes for backspace, delete, enter
				if (keyCode != 0 && keyCode != 8 && keyCode != 13 && !ev.ctrlKey) 
				{
					ev.preventDefault();
				}
			}
		});
		jQuery(".WhiteCapOrderForms_ListPanel_unitlength").keydown(function(e){
			var key = e.which;

			// backspace, tab, left arrow, up arrow, right arrow, down arrow, delete, numpad decimal pt, period, enter
			if (key != 8 && key != 37 && key != 38 && key != 39 && key != 40 && key != 46 && key != 110 && key != 190 && key != 13){
				if (key < 48){
					e.preventDefault();
				}
				else if (key > 57 && key < 96){
					e.preventDefault();
				}
				else if (key > 105) {
					e.preventDefault();
				}
			}
		});

	},

	// ------------------------------------------------------------------------
	// Button click event handlers
	// ------------------------------------------------------------------------
	
	_onClickList : function(e)
	{
		WhiteCapOrderForms.CartDialogActive = true;
		var windowTitle = this._activeOrderFormName;
		this._popUpWindow.setTitle(windowTitle);
		
		this._addPanel_AddContainer.hide();
		this._continue_container.show();
		this._continueBtn.hide();
		this._change_order_container.show();
		this._changeOrderBtn.show();
		this._mchangeOrderBtn.show();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._place_container.hide();

		this._addPanel_AddBtn.hide();
		this._addPanel_CreateNewOrderBtn.hide();
		this._addOrderPanel_AddOrderBtn.hide();
		this._placeBtn.hide();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._buttonContainer.removeClass('WhiteCapOrderForms_AddDialog');
		if (this._orderItems.length == 0)
		{
			this._emailBtn.hide();
			this._memailBtn.hide();
			this._printBtn.hide();
			this._orderBtn.hide();
			this._clearallBtn.hide();
			this._mclearallBtn.hide();
			this._editBtn.hide();
			this._doneBtn.hide();
			this._continueBtn.hide();
			this._changeOrderBtn.show();
			this._mchangeOrderBtn.show();
			this._listPanel_EmptyMessage.show();	
		}	
		else
		{
			this._emailOrder_container.show();
			this._emailBtn.show();
			this._memailBtn.show();
			this._printBtn.hide();
			this._orderBtn.show();
			this._clearallBtn.show();
			this._mclearallBtn.show();
			this._editBtn.show();
			this._listPanel_EmptyMessage.hide();			
		}	
		if (this._orderItems.length == 0)
		{
			this._emailOrder_container.show();
			this._orderBtn.hide();
		}
		else
		{
			this._emailOrder_container.show();
			this._orderBtn.show();
		}
		this._doButtonContainerLayout();
		this._displayItems();
		this._sentPanel.hide();
		this._emailPanel.hide();
		this._addPanel.hide();
		this._addOrderPanel.hide();
		this._placeOrderPanel.hide();
		this._listPanel.show();
	},

	_onOrderFormNameInputKeydown : function(e)
	{
		if (e.code == '16')
			return;

		if ((e.code == '186') || (e.code == '187') || (e.code == '188') || ((e.code == '190') && (e.shift == true)) || (e.code == '191') || (e.code == '192') || (e.code == '219') || (e.code == '220') || (e.code == '221') || (e.code == '222'))
		{
       		event.preventDefault();
       		return false;			
		}
	   	this._filterOrders.delay(1,this);
  	},
	
	_selectAddOrder : function()
	{
		this._widgetRootElement.getElementById('WhiteCapOrderForms_AddOrderPanel_Name').value = '';
		this._addPanel_AddContainer.hide();
		this._continue_container.hide();
		this._change_order_container.hide();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._emailBtn.hide();
		this._memailBtn.hide();
		this._printBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.hide();
		this._changeOrderBtn.hide();
		this._mchangeOrderBtn.hide();
		this._addPanel_AddBtn.hide();
		this._addPanel_CreateNewOrderBtn.hide();
		this._addOrderPanel_AddOrderBtn.show();
		this._buttonContainer.addClass('WhiteCapOrderForms_AddDialog');
		this._sentPanel.hide();
		this._emailPanel.hide();
		this._placeOrderPanel.hide();
		this._listPanel.hide();
		this._addPanel.hide();
		
		var ordersText = '';
		orderNameArray = new Array();
		orderItemArray = new Array();
		for (var i=this._orders.length-1;i>=0;i--)
		{
			var curOrderNum = this._orders[i].orderNumber;
			var currentOrderFormName = this._orders[i].orderName;
			
			ordersText += '<div id=\"WhiteCapOrderForms_Order_wrapper_' + curOrderNum + '\" class=\"WhiteCapOrderForms_Order\">';
			ordersText += '		<div class=\"WhiteCapOrderForms_AddPanel_Title ten columns\">' + currentOrderFormName + '</div>';
			ordersText += '		<div class=\"WhiteCapOrderForms_ListPanel_delete two columns\">';
			ordersText += '			<div id=\"' + curOrderNum + '_rmv\" class=\"WhiteCapOrderForms_OrderListPanel_remove glyphicon glyphicon-ban-circle\"></div>';
			ordersText += '		</div>';
			ordersText += '</div>';			
		}	    
		this._orderListPanel_ListElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_OrderListPanel_theList');
	    this._orderListPanel_ListElement.set('html', ordersText);
	    
		var theElementList;

		//Loop through remove events
		theElementList = this._orderListPanel_ListElement.getElements('.WhiteCapOrderForms_OrderListPanel_remove');
		theElementList.each(function(order, index)
		{
			order.addEvent('click', this._remOrder.bind(this));
			order.mooTouchAdd({'click':true});
		}.bind(this));
		
		theElementList = this._orderListPanel_ListElement.getElements('.WhiteCapOrderForms_Order');
		theElementList.each(function(order, index)
		{
			order.addEvent('click', this._onSetActiveOrder.bind(this));
			order.mooTouchAdd({'click':true});
		}.bind(this));
	    
		this._addOrderPanel.show();
	},

	_onChangeActiveOrder : function(orderName, orderNumber)
	{
		this._activeOrder = [];
		this._activeOrder.orderName = orderName;
		this._activeOrder.orderNumber = orderNumber;
		this._activeOrderFormName = orderName;
		this._appState.set(AppState.activeOrder,this._activeOrder);
		
		if (this._activeOrder.orderName)
		{
			this._orderItems = Preferences.getInstance().get('WhiteCapOrderForms'+this._activeOrder.orderNumber);
			if (!this._orderItems)
				this._orderItems = [];	
		}
		else
			this._orderItems = [];		
		
		//Facade.getInstance().sendNotification.delay(1,Facade.getInstance(),[WhiteCapOrderForms.ReloadActiveOrderItems]);
		Facade.getInstance().sendNotification(WhiteCapOrderForms.ReloadActiveOrderItems);
		if (!this._activeOrderFormName)
			this._popUpWindow.setTitle('');	
		else if (this._data && this._activeOrderFormName)
		{
			var windowTitle = this._activeOrderFormName;
			this._popUpWindow.setTitle(windowTitle);			
		}
	},
	
	_onSetActiveOrder : function(e,theOrderId)
	{
		var theOrder;
		
		theOrder = e.target;
		theOrderId = theOrder.get('id');
		if (!theOrderId)
			theOrderId = theOrder.getParent().get('id');
		var npos = theOrderId.lastIndexOf('_');
		if (npos != -1)
			theOrderId = theOrderId.substr(npos+1);
			
		for (var i=0;i<this._orders.length;i++)
		{
			if (this._orders[i].orderNumber == theOrderId)
			{
				this._onChangeActiveOrder(this._orders[i].orderName, this._orders[i].orderNumber);
				break;
			}	
		}
			
		if (this._activeOrderFormName)
		{
			var windowTitle = this._activeOrderFormName;
			this._popUpWindow.setTitle(windowTitle);				
		}
		if (!this._data)
			this._showOrderMax();
	},

	_updateExistingOrderDropdown : function ()
	{
		var posOffset = 0;
		this._addPanel_OrderNameDropdown.options.length = 0;
		
		if (!this._activeOrderFormName)
		{
			var option = document.createElement('option');
			option.value = '';
			option.disabled = true;
			option.text = '<Select List>';
			option.value = '';
			this._addPanel_OrderNameDropdown.add(option);	
			this._selectedItemPos = 0;
			posOffset = 1;
		}
			
		for (var i=this._orders.length-1;i>=0;i--)
		{
			var option = document.createElement('option');
			option.text = this._orders[i].orderName;
			option.value = this._orders[i].orderNumber;
			var pos = (this._orders.length-1) - i + posOffset;
			if (this._orders[i].orderName == this._activeOrderFormName)
				this._selectedItemPos = pos;
			this._addPanel_OrderNameDropdown.add(option);
		}
		this._addPanel_OrderNameDropdown.selectedIndex = this._selectedItemPos;
	},
	
	_onAddList : function(e)
	{
		
		if ((this._orders.length != this._addPanel_OrderNameDropdown.options.length) || ((this._selectedItemPos == null) || (this._selectedItemPos == undefined)))
			this._updateExistingOrderDropdown();
				
		if (this._activeOrderFormName)
		{
			this._addPanel_OrderNameDropdown.selectedIndex = this._selectedItemPos;
		}
		else
			this._addPanel_OrderNameDropdown.selectedIndex = this._selectedItemPos;
				
		if (this._data)
		{		
			var currentOrderNameString = '';
			if (this._activeOrderFormName)
				currentOrderNameString = this._activeOrderFormName;
			
			//this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_Title').set('html', '<br><br>Title: ' + this._data.find('title').text());
			this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_Title').set('html', '<br><br>Part No.: ' + this._data.find('sku').text());
			//this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_Model').set('html', 'Model: ' + this._data.find('model').text());
			this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_Description').set('html', 'Description: ' + this._data.find('desc').text());
			var cart_currency = Skin.getInstance().get('CartCurrency', '$');
			this._widgetRootElement.getElement('#WhiteCapOrderForms_AddPanel_Price').set('html', 'Unit Price: ' + cart_currency+this._data.find('price').text());
			unitlength = this._data.find('length').text();
			if (unitlength != '0')
			{
				this._length_warning.hide();
			}
			else
			{
				this._length_warning.show();
			}
		}	
		
		this._addPanel_AddContainer.show();
		this._change_order_container.hide();
		this._continue_container.hide();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();

		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._emailBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.hide();
		this._changeOrderBtn.hide();
		this._mchangeOrderBtn.hide();
		this._addPanel_AddBtn.show();
		this._addPanel_CreateNewOrderBtn.show();
		this._buttonContainer.addClass('WhiteCapOrderForms_AddDialog');
	
		this._sentPanel.hide();
		this._emailPanel.hide();
		this._placeOrderPanel.hide();
		this._listPanel.hide();
		this._addOrderPanel.hide();
		this._addPanel.show();
	},

	_onClickEmail : function(e)
	{
		this._addPanel_AddContainer.hide();
		this._continue_container.show();
		this._change_order_container.show();
		this._emailOrder_container.hide();
		this._sendorder_container.hide();
		this._send_container.show();

		this._addPanel_AddBtn.hide();
		this._addPanel_CreateNewOrderBtn.hide();
		this._addOrderPanel_AddOrderBtn.hide();
		this._continueBtn.hide();
		this._changeOrderBtn.hide();
		this._mchangeOrderBtn.hide();
		this._emailBtn.hide();
		this._memailBtn.hide();
		this._printBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.show();
		this._changeOrderBtn.show();
		this._mchangeOrderBtn.show();
		this._backBtn.show();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._send_orderBtn.hide();
		this._sendBtn.show();
		this._doButtonContainerLayout();

		this._sentPanel.hide();
		this._placeOrderPanel.hide();
		this._listPanel.hide();
		this._addPanel.hide();
		this._addOrderPanel.hide();
		
		this._emailPanel.show();
		this._popUpWindow.windowDiv.restoreIcon.hide();
		this._changeOrderBtn.hide();
		this._mchangeOrderBtn.hide();
	},

	_onClickSend : function(e)
	{
		// SAWS (Stunnix Advance Web Server) test required to support emails if network connection exists.
		if (this._appState.get('isSAWS',false) == true)
		{
			var NetworkConnectionErrorTitle = Skin.getInstance().get('NetworkConnectionErrorTitle', 'Need network connection');
			var NetworkConnectionError = Skin.getInstance().get('NetworkConnectionError', 'You will need to establish an internet connection to use this feature.');

			var xhr = new XMLHttpRequest();
			var file = Skin.getInstance().get('ServicePath') + RELATIVE_PATH_TO_CODE + 'components/custom/' + this.componentName + '/ServiceEmailList.php';
			var randomNum = Math.round(Math.random() * 10000);

			xhr.open('HEAD', file + "?rand=" + randomNum, false);

			try {
				xhr.send();
				if (xhr.status >= 200 && xhr.status < 304) {
					this._onClickSend2(e);//return true;
				} else {
					Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:NetworkConnectionError, title:NetworkConnectionErrorTitle});
					return false;
				}
			} catch (e) {
				Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:NetworkConnectionError, title:NetworkConnectionErrorTitle});
				return false;
			}
		}
		else
		{
			this._onClickSend2(e);
		}
	},
	
	_onClickSend2 : function(e)
	{
		this._emailElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_EmailPanel');
		var theLanguageList, theLanguageIndex, theLanguageCode;
		theLanguageList = this._appState.get(currentLanguageList);
		theLanguageIndex = this._appState.get(currentLanguageIndex);
		theLanguageCode = theLanguageList.getLanguageCode(theLanguageIndex);

		var length = (this._orderItems.length*this._fields);
		var element = this._emailElement.getElementById('WhiteCapOrderForms_EmailPanel_ToNameField');
		var toName = element.value;
		var element = this._emailElement.getElementById('WhiteCapOrderForms_EmailPanel_ToEmailField');
		var toEmail = element.value;
		var element = this._emailElement.getElementById('WhiteCapOrderForms_EmailPanel_CompanyName');
		var toCompanyName = element.value;
		var element = this._emailElement.getElementById('WhiteCapOrderForms_EmailPanel_Zip');
		var toZip = element.value;		
		var element = this._emailElement.getElementById('WhiteCapOrderForms_EmailPanel_NotesField');
		var notes = escape(element.value);
		var element = this._emailElement.getElementById('WhiteCapOrderForms_EmailCheckBox');
		var echeckbox = escape(element.checked);		

		//validate form input
		toEmail = toEmail.trim();
		if (!FieldValidation.getInstance().isEmailValid(toEmail, 'Recipients Email'))
			return;
		if (!FieldValidation.getInstance().isNameValid(toName, 'Recipients Name'))
			return;	
			
		this._addPanel_AddContainer.hide();
		this._change_order_container.show();
		this._continue_container.show();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.hide();

		this._addPanel_AddBtn.hide();
		this._addPanel_CreateNewOrderBtn.hide();
		this._addOrderPanel_AddOrderBtn.hide();
		this._emailBtn.hide();
		this._memailBtn.hide();
		this._printBtn.hide();
		this._orderBtn.hide();
		this._backBtn.hide();
		this._back_sentBtn.show();
		this._back_orderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._doButtonContainerLayout();
		
		var data1 = '';
		for (var i = 0; i < this._orderItems.length; i++)
		{
			data1 += escape(this._orderItems[i].sku)+'**'+escape(this._orderItems[i].desc)+'**'+escape(this._orderItems[i].qty)+'**'+escape(this._orderItems[i].price)+'**';
		}
	
		var cart_currency = Skin.getInstance().get('CartCurrency', '$');
		var postBody = 'lang='+theLanguageCode+'&length='+length+'&ds='+cart_currency+'&toName='+escape(toName)+'&toEmail='+toEmail+'&toCompanyName='+escape(toCompanyName)+'&toZip='+escape(toZip)+'&echeckbox='+escape(echeckbox)+'&notes='+notes+'&data1='+escape(data1);
		var pathToCode = this._getBasePath();
		var isPhoneGap = (window.cordova) ? true : false;
		var theServicePath = REMOTE_PATH_TO_SERVICES;
		if (isPhoneGap)
			pathToCode = theServicePath + pathToCode;
		if (this._appState.get('isSAWS',false) == true)
			pathToCode = Skin.getInstance().get('ServicePath') + RELATIVE_PATH_TO_CODE + 'components/custom/' + this.componentName + '/';

		// We only need the CORS for SAWS/Firefox because we are sending from localhost to live site.
		// So, we'll stick with the old method for IE.
		
		//var myHTMLRequest = new Request.HTML({url: pathToCode + 'ServiceEmailList.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?')}).post(postBody);
// We only need the CORS for SAWS/Firefox because we are sending from localhost to live site.
		// So, we'll stick with the old method for IE.
		if (Browser.ie && Browser.version < 11)
		{
			var myHTMLRequest = new Request.HTML({url: pathToCode + 'ServiceEmailList.php'+CacheMgr.getInstance().getResourceCacheArg('RelId','?')}).post(postBody);
		}
		else
		{		
			this._request = new Request.CORS(
			{
				method: 'post',
				noCache: true,
				url: pathToCode + 'ServiceEmailList.php',
				data: postBody,
				onSuccess: function(responseText, responseXml)
				{ 
					//console.log(responseText);
				}.bind(this),
				onFailure: function(obj)
				{
					Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:"ServiceEmailList Error"});
				}.bind(this)
			});
			this._request.send();
		}




		this._widgetRootElement.getElement('#WhiteCapOrderForms_SentPanel_ToName').set('html', toName);
		this._widgetRootElement.getElement('#WhiteCapOrderForms_SentPanel_ToEmail').set('html', toEmail);

		if(jQuery('#WhiteCapOrderForms_EmailCheckBox').is(':checked'))
		{
			this._widgetRootElement.getElement('#WhiteCapOrderForms_ThanksMsg').set('html', 'Thank you for using the White Cap Project List! Your email has been sent!');
		}
		else
		{
			this._widgetRootElement.getElement('#WhiteCapOrderForms_ThanksMsg').set('html', 'Thank you for using the White Cap Project List! Your email has been sent!');
		}
		
		var dialogName = this.componentName;
		dialogName = dialogName.replace('DialogView', '');
		Facade.getInstance().sendNotification(ApplicationFacade.LOG_EVENT, {category:dialogName, action:'Emailed'});

		this._placeOrderPanel.hide();
		this._listPanel.hide();
		this._emailPanel.hide();
		this._addPanel.hide();
		this._addOrderPanel.hide();
		this._sentPanel.show();
		this._backBtn.show();
	},

	_onClickOrder : function(e)
	{
		//this._post_to_localhost();
		this._onClickEmail(e);
		//this._onClickSendOrder(e);
	/*	var msg = Skin.getInstance().get('WhiteCapOrderFormsSentMsg','Your Order has been sent');
		var title = Skin.getInstance().get('WhiteCapOrderFormsSentTitle','Order Sent');
		Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:msg, title:title,callback:function()
		{
			this._popUpWindow.close();
		}.bind(this)});*/
		//return;
		
		/*this._addPanel_AddContainer.hide();
		this._change_order_container.show();
		this._continue_container.show();
		this._emailOrder_container.hide();
		this._send_container.hide();
		this._sendorder_container.show();

		this._addPanel_AddBtn.hide();
		this._addPanel_CreateNewOrderBtn.hide();
		this._addOrderPanel_AddOrderBtn.hide();
		this._continueBtn.hide();
		this._changeOrderBtn.hide();
		
		this._emailBtn.hide();
		this._memailBtn.hide();
		this._printBtn.hide();
		this._orderBtn.hide();
		this._continueBtn.hide();
		this._changeOrderBtn.show();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.show();
		this._sendBtn.hide();
		this._send_orderBtn.show();
		this._doButtonContainerLayout();

		this._sentPanel.hide();
		this._listPanel.hide();
		this._addPanel.hide();
		this._emailPanel.hide();
		this._placeOrderPanel.show();*/
	},
	
	_onClickSendOrder : function(e)
	{
		var params = {};
		
		var data1 = '';
		for (var i = 0; i < this._orderItems.length; i++)
		{
			data1 += escape(this._orderItems[i].sku)+'**'+escape(this._orderItems[i].description)+'**'+escape(this._orderItems[i].unitlength)+'**'+escape(this._orderItems[i].price)+'**'+escape(this._orderItems[i].qty)+'**';
		}
		
		var cart_currency = Skin.getInstance().get('CartCurrency', '$');
		var theLanguageList, theLanguageIndex, theLanguageCode;
		theLanguageList = this._appState.get(currentLanguageList);
		theLanguageIndex = this._appState.get(currentLanguageIndex);
		theLanguageCode = theLanguageList.getLanguageCode(theLanguageIndex);

		var length = (this._orderItems.length*this._fields);
		var theCompanyCode = Skin.getInstance().get("DefaultCompanyCode");
		var theBook = this._appState.get(currentBook);
		var theBookCode = theBook.bookCode;
		
		params['data1'] = data1;
		params['lang'] = theLanguageCode;
		params['length'] = length;
		params['fields'] = this._fields;
		params['currency'] = cart_currency;
		params['CompanyCode'] = theCompanyCode;
		params['BookCode'] = theBookCode;
	
		this._placeOrderPanelElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_PlaceOrderPanel');
		//validate form input
		var element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingNameField');
		var bName = element.value;
		if (!FieldValidation.getInstance().isNameValid(bName, 'Billing Name'))
			return;
		params['Name'] = bName;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingAddressField');
		var bAddress = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(bAddress, 'Billing Address'))
			return;
		params['Address'] = bAddress;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingCityField');
		var bCity = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(bCity, 'Billing City'))
			return;
		params['City'] = bCity;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingStateField');
		var bState = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(bState, 'Billing State'))
			return;
		params['State'] = bState;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingZipCodeField');
		var bZip = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(bZip, 'Billing Zip Code'))
			return;
		params['ZipCode'] = bZip;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingPhoneNumberField');
		var bPhone = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(bPhone, 'Billing Phone Number'))
			return;
		params['PhoneNumber'] = bPhone;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingCountryField');
		var bCountry = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(bCountry, 'Billing Country'))
			return;
		params['Country'] = bCountry;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingEmailAddressField');
		var bEmail = element.value;
		bEmail = bEmail.trim();
		if (!FieldValidation.getInstance().isEmailValid(bEmail, 'Email Address'))
			return;
		params['EmailAddress'] = bEmail;
			
		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_BillingEmailAddressField');
		var bEmail2 = element.value;
		bEmail2 = bEmail2.trim();
		if (!FieldValidation.getInstance().isEmailValid(bEmail2, 'Email Address'))
			return;
			
		if (bEmail != bEmail2)
		{
			Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:"Email address doesn't match confirm email address field.", title:title});
			return;
		}
		
		element = this._placeOrderPanelElement.getElementById('referenceSourceDropdown');
		var bSource = element.value;
		params['referenceSource'] = bSource;
		
		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_PromoCodeField');
		var bPromoCode = element.value;
		params['PromoCode'] = bPromoCode;
		
		element = this._placeOrderPanelElement.getElementById('shippingMethodDropdown');
		var bShippingOptions = element.value;
		params['shippingMethod'] = bShippingOptions;

		if (this._placeOrderPanelElement.getElementById('backorder1').checked==true)
			params['backorder'] = 'Yes';
		else
			params['backorder'] = 'No';
			
		if (this._placeOrderPanelElement.getElementById('newcatalog1').checked==true)
			params['newcatalog'] = 'Yes';
		else
			params['newcatalog'] = 'No';

		if (this._placeOrderPanelElement.getElementById('shipmatchesbill2').checked==true)
		{
			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingNameField');
			var sName = element.value;
			if (!FieldValidation.getInstance().isNameValid(sName, 'Shipping Name'))
				return;
			params['ShipName'] = sName;

			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingAddressField');
			var sAddress = element.value;
			if (!FieldValidation.getInstance().isFieldPopulated(sAddress, 'Shipping Address'))
				return;
			params['ShipAddress'] = sAddress;

			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingCityField');
			var sCity = element.value;
			if (!FieldValidation.getInstance().isFieldPopulated(sCity, 'Shipping City'))
				return;
			params['ShipCity'] = sCity;

			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingStateField');
			var sState = element.value;
			if (!FieldValidation.getInstance().isFieldPopulated(sState, 'Shipping State'))
				return;
			params['ShipState'] = sState;

			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingZipCodeField');
			var sZip = element.value;
			if (!FieldValidation.getInstance().isFieldPopulated(sZip, 'Shipping Zip Code'))
				return;
			params['ShipZipCode'] = sZip;

			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingPhoneField');
			var sPhone = element.value;
			if (!FieldValidation.getInstance().isFieldPopulated(sPhone, 'Shipping Phone'))
				return;
			params['ShipPhoneNumber'] = sPhone;

			element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingCountryField');
			var sCountry = element.value;
			if (!FieldValidation.getInstance().isFieldPopulated(sCountry, 'Shipping Country'))
				return;
			params['ShipCountry'] = sCountry;
		}
		else
		{
			params['ShipName'] = bName;
			params['ShipAddress'] = bAddress;
			params['ShipCity'] = bCity;
			params['ShipState'] = bState;
			params['ShipZipCode'] = bZip;
			params['ShipPhoneNumber'] = bPhone;
			params['ShipCountry'] = bCountry;
		}

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_VehicleYearField');
		var vehYear = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(vehYear, 'Vehicle Year'))
			return;
		params['VehicleYear'] = vehYear;

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_VehicleMakeField');
		var vehMake = element.value;
		if (!FieldValidation.getInstance().isFieldPopulated(vehMake, 'Vehicle Make'))
			return;
		params['VehicleMake'] = vehMake;
			
		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_VehicleModelField');
		var vehModel = element.value;
		params['VehicleModel'] = vehModel;
		
		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_VehicleNotesField');
		var Notes = element.value;
		params['VehicleNotes'] = Notes;
		
		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ExtraVehicleNotesField');
		var ExtraNotes = element.value;
		params['ExtraVehicleNotes'] = ExtraNotes;
		
		var theBookPageIndex = this._appState.get(currentBookPageDest).BookPageIndex;
		var secidx = book.getSectionIndex(theBookPageIndex);
		theBookPageIndex = theBookPageIndex.toInt();
		
		// Empty the cart items from the dialog
		this._onClearAll();
		var aspfile = (RELATIVE_PATH_TO_CODE.indexOf('-bin')>-1) ? '' : 'debug.asp';
		theUrlStr = REMOTE_PATH_TO_SERVICES += aspfile+'?BookCode='+theBookCode+'&Sgt='+secidx+'&PageLabel='+theBook.getPageLabel(theBookPageIndex);
		theImageUrlStr = REMOTE_PATH_TO_SERVICES + this._getBasePath()
		params['return_url'] = theUrlStr;
		params['image_url'] = theImageUrlStr;
		this._post_to_url(REMOTE_PATH_TO_SERVICES + this._getBasePath() + 'ServiceCheckOut.php', params);
		Facade.getInstance().sendNotification(ApplicationFacade.LOG_EVENT, {category:this.componentName.replace('DialogView',''), action:'Checkout'});
	},
	
	_post_to_url : function(path, params, method) 
	{
	    method = method || "post"; // Set method to post by default, if not specified.

	    // The rest of this code assumes you are not using a library.
	    // It can be made less wordy if you use one.
	    var form = document.createElement("form");
	    form.setAttribute("method", method);
	    form.setAttribute("action", path);

	    for(var key in params) {
	        if(params.hasOwnProperty(key)) {
	            var hiddenField = document.createElement("input");
	            hiddenField.setAttribute("type", "hidden");
	            hiddenField.setAttribute("name", key);
	            hiddenField.setAttribute("value", params[key]);

	            form.appendChild(hiddenField);
	         }
	    }

	    document.body.appendChild(form);
	    form.submit();
	},
	
	_onShipMatchesBilling : function(e)
	{
		this._placeOrderPanelElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_PlaceOrderPanel');
		var element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingNameField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingAddressField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingCityField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingStateField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingZipCodeField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingPhoneField');
		element.disabled = true;
		element.value = 'Using Billing Information';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingCountryField');
		element.disabled = true;
		element.value = 'Using Billing Information';
	},
	
	_onShipDoesntMatchBilling : function(e)
	{
		this._placeOrderPanelElement = this._widgetRootElement.getElement('#WhiteCapOrderForms_PlaceOrderPanel');
		var element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingNameField');
		element.disabled = false;
		element.value = '';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingAddressField');
		element.disabled = false;
		element.value = '';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingCityField');
		element.disabled = false;
		element.value = '';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingStateField');
		element.disabled = false;
		element.value = '';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingZipCodeField');
		element.disabled = false;
		element.value = '';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingPhoneField');
		element.disabled = false;
		element.value = '';

		element = this._placeOrderPanelElement.getElementById('WhiteCapOrderForms_PlaceOrderPanel_ShippingCountryField');
		element.disabled = false;
		element.value = '';
	},

	_onClearAll : function(e)
	{
		this._orderItems = [];
		Preferences.getInstance().set('WhiteCapOrderFormsCart', this._orderItems);
		if (this._activeOrder && this._activeOrder.orderNumber)
			Preferences.getInstance().set('WhiteCapOrderForms'+this._activeOrder.orderNumber, this._orderItems);
		Facade.getInstance().sendNotification(WhiteCapOrderForms.ReloadActiveOrderItems);
	},
	
	_onClickBackToOrder : function(e)
	{
		this._displayItems()
		this._showOrderMax();	
	},
	
	_onClickBack : function(e)
	{
		this._onClickBackToOrder(e);
		/*
		this._addPanel_AddContainer.hide();
		this._change_order_container.show();
		this._continue_container.show();
		this._emailOrder_container.show();
		this._send_container.hide();
		this._sendorder_container.hide();
		this._place_container.hide();

		this._addPanel_AddBtn.hide();
		this._addPanel_CreateNewOrderBtn.hide();
		this._addOrderPanel_AddOrderBtn.hide();
		this._sendBtn.hide();
		this._send_orderBtn.hide();
		this._orderBtn.show();
		this._backBtn.hide();
		this._back_sentBtn.hide();
		this._back_orderBtn.hide();
		this._emailBtn.show();
		this._memailBtn.show();
		this._printBtn.hide();
		this._doButtonContainerLayout();

		this._emailPanel.hide();
		this._sentPanel.hide();
		this._addPanel.hide();
		this._placeOrderPanel.hide();
		this._listPanel.show();	
		*/	
	},
	
	_onClickPrint : function(e)
	{  
		var windowContent = '<!DOCTYPE html>';
		windowContent += '<html>'
		windowContent += '<head><title>White Cap&reg; Inc.</title>';
		windowContent += '<link type=\"text/css\" rel=\"stylesheet\" href=\"' + this._getBasePath() + this.componentName + '.css\" />';
		windowContent += '</head>';
		windowContent += '<body><div id=\"WhiteCapOrderForms_ListPanel\">';
		for (var i = 0; i < this._orderItems.length; i++)
		{
			windowContent += '<div id=\"WhiteCapOrderForms_ListPanel_itemwrapper_'+i+'\" class=\"WhiteCapOrderForms_ListPanel_item\">';
			windowContent += '<div class=\"WhiteCapOrderForms_ListPanel_description\">Description: '+this._orderItems[i].description+'</div>';
			windowContent += '<div class=\"WhiteCapOrderForms_ListPanel_sku\">Part Number: '+this._orderItems[i].sku+'</div>';
			windowContent += '<div class=\"WhiteCapOrderForms_ListPanel_length\">Length: '+this._orderItems[i].unitlength+'</div>';			
			windowContent += '<div class=\"WhiteCapOrderForms_ListPanel_price\">Unit of Measurement: '+this._orderItems[i].price+'</div>';
			windowContent += '<div class=\"WhiteCapOrderForms_ListPanel_qty_'+i+'\">Quantity: '+this._orderItems[i].qty+'</div>';
			windowContent += '<br>';
			
			windowContent += '</div>';
		}
		windowContent += '</div></body>';
		windowContent += '</html>';
		
		Facade.getInstance().sendNotification(ApplicationFacade.PRINT_TEXT, {content:windowContent});
		Facade.getInstance().sendNotification(ApplicationFacade.LOG_EVENT, {category:'Shopping List', action:'Printed'});
		this._popUpWindow.close();	
	},	
		
	_doButtonContainerLayout : function()
	{
		// Set the container left to zero before measuring to make sure buttons will all fit side by side without wrapping
		this._buttonActionCenter.setStyle('left',0);
		var theParentSize = this._buttonContainer.measure(function(){return this.getSize();});
		var theSize = this._buttonActionCenter.measure(function(){return this.getSize();});
		this._buttonActionCenter.setStyle('left',(theParentSize.x/2) - (theSize.x/2));
	},

	_keepEditState : function()
	{
		jQuery(function() {
		    jQuery('.WhiteCapOrderForms_ListPanel_remove').show();
		    jQuery('#WhiteCapOrderForms_button_edit').hide();
		    jQuery(".WhiteCapOrderForms_ListPanel_qty").prop("disabled",false);
		});		
	},

	_onIncrementBtn : function(e)
	{
		
		var curValue = this._qtyInput.value;
		var curNumber = parseFloat(curValue);
		if (curNumber < 9999)
			this._qtyInput.value = curNumber+1;
	},
	
	
	_onDecrementBtn : function(e)
	{
	    var curValue =  this._qtyInput.value;
	    var curNumber = parseFloat(curValue);
	    if ( curNumber >= 2) 
			this._qtyInput.value = curNumber - 1;
	
	},

	_onOrderDropdownSelect : function(e)
	{
		var text = this._addPanel_OrderNameDropdown.value;
		this._selectedItemPos = this._addPanel_OrderNameDropdown.selectedIndex;
		if (text == 'selectAddOrder')
			this._selectAddOrder();
		else
		{
			for (var i=0;i<this._orders.length;i++)
			{
				if (this._orders[i].orderNumber == text)
				{
					this._onChangeActiveOrder(this._orders[i].orderName, this._orders[i].orderNumber);
					if (this._addPanel_OrderNameDropdown[0].value == '')
						this._addPanel_OrderNameDropdown.remove(0);
					break;
				}
			}	
		}			
	},
	
	_onCreateNewOrder : function(e)
	{
		var msg = Skin.getInstance().get('WhiteCapOrderFormsCreateNewOrderNameMsg','List Name:');
		var title = Skin.getInstance().get('WhiteCapOrderFormsCreateOrderNameTitle','Create New List');	
		var sizeLimit = Skin.getInstance().get('WhiteCapOrderFormsOrderNameSizeLimit','25');	
		// Hide the current popup 
		this._popUpWindow.windowDiv.hide();
		Facade.getInstance().sendNotification(ApplicationFacade.LOAD_COMPONENT, {Name:'Ask', HasCss:true, Data:{Title:title, Message:msg, Pattern:'^[:;+=,<>?{}\\]\\[\\/\\\\]+$', InputLimitSize:sizeLimit, Callback:function(result)
		{
			var orderFormName = result;
			if ((orderFormName == null) || (orderFormName == ''))
			{
				// Restore the current popup
				this._popUpWindow.windowDiv.show();
				PopUpWindow.showModalOverlay.delay(1,this);	
				return;
			}
			
			var order_cnt = this._orders.length;
			// find next available order number
			///var orderNum = "Order_0000";
			var orderNum = "Order0";
			var orderNameExists = false;
			for (var i=0;i<order_cnt;i++)
			{
				var orderName = this._orders[i].orderName;
				if (orderName.toUpperCase() == orderFormName.toUpperCase())
				{
					orderNameExists = true;
					orderNum = this._orders[i].orderNumber;
					break;
				}
				if (orderNameExists)
					break;
			}
			
			if (!orderNameExists)
			{
				for (var i=0;i<10000;i++)
				{
					if (i>order_cnt)
						break;
					// pad the number to four digits
					///var padOrderNum= "0000" + i;
					var foundMatch = false;
					///orderNum = "Order_" + padOrderNum.slice(-4);
					orderNum = "Order" + i;
					for (var n=0;n<order_cnt;n++)
					{
						var orderNumber = this._orders[n].orderNumber;
						if (orderNumber == orderNum)
						{
							// we found an open slot so 	
							foundMatch = true;
							break;
						}
					}
					if (!foundMatch)
						break;
				}
				
				this._orders.push({orderNumber:orderNum,orderName:orderFormName});
				Preferences.getInstance().set('WhiteCapOrderFormsOrders', this._orders);
				this._popUpWindow.windowDiv.show();
				PopUpWindow.showModalOverlay.delay(1,this);	
			}
			else
			{
				var msg = Skin.getInstance().get('WhiteCapOrderFormsOrderExistsMsg','This list name already exists.  Would you like to switch to this list?');
				var title = Skin.getInstance().get('WhiteCapOrderFormsOrderExistsTitle','List Name Exists');
				var y = Skin.getInstance().get('YesButton', 'Yes');
				var n = Skin.getInstance().get('NoButton', 'No');			
				Facade.getInstance().sendNotification(ApplicationFacade.ALERT_CONFIRM, {message:msg, title:title, leftbutton:y, rightbutton:n, callback:function(result)
				{
					if (result == true)
					{
						var ordersText = '';
						ordersText += '<div class=\"WhiteCapOrderForms_Order\">';
						ordersText += '		<div class=\"WhiteCapOrderForms_AddPanel_Title ten columns\">' + orderNum + '</div>';
						ordersText += '		<div class=\"WhiteCapOrderForms_ListPanel_delete two columns\">';
						ordersText += '			<div id=\"' + orderNum + '\" class=\"WhiteCapOrderForms_OrderListPanel_remove glyphicon glyphicon-ban-circle\"></div>';
						ordersText += '		</div>';
						ordersText += '</div>';
						this._onChangeActiveOrder(orderFormName, orderNum);
						this._updateExistingOrderDropdown();
					}
					else
						this._widgetRootElement.getElementById('WhiteCapOrderForms_AddOrderPanel_Name').value = '';
					this._popUpWindow.windowDiv.show();
					PopUpWindow.showModalOverlay.delay(1,this);	
				}.bind(this)});
				
				return;	
			}				
			this._onChangeActiveOrder(orderFormName, orderNum);
			if (this._activeOrderFormName)
			{
				var windowTitle = this._activeOrderFormName;
				this._popUpWindow.setTitle(windowTitle);				
			}
		
			if (this._data)
				this._updateExistingOrderDropdown();
			else
				this._showOrderMax();
			//	this._selectAddOrder();	
			PopUpWindow.showModalOverlay.delay(1,this);	
		}.bind(this)}});

	},
	
	_updateOrderList : function()
	{
		if (!this._data)
		{
			this._activeOrder = this._appState.get(AppState.activeOrder);
			if (this._activeOrder && this._activeOrder.orderNumber)
			{
				this._activeOrderFormName = this._activeOrder.orderName;
				this._orderItems = Preferences.getInstance().get('WhiteCapOrderForms'+this._activeOrder.orderNumber);
				if (!this._orderItems)
					this._orderItems = [];	
			}
			else
				this._orderItems = [];
				
			if (this._activeOrderFormName)
			{
				this._popUpWindow.setTitle(this._activeOrderFormName);	
				this._displayItems();			
			}
			else
			{
				this._popUpWindow.setTitle('');	
			}
		}	
	},
	
	_post_to_localhost : function() 
	{
		var port,port_override;
		var jsonArr = [];
		
		for (var i = 0; i < this._orderItems.length; i++) 
		{
		    var sku_val = this._orderItems[i].sku;
		    var qty_val = this._orderItems[i].qty;
		    if (qty_val == 0)
		    	qty_val = '';
		    jsonArr.push(
		    {
		        sku: sku_val,
		        qty: qty_val
		    });
		}
		
		var url = Skin.getInstance().get('WhiteCapOrderFormsPostUrl','http://localhost');
		
		port = Skin.getInstance().get('WhiteCapOrderFormsDefaultPortNumber', '49362');
		port_override = Preferences.getInstance().get('WhiteCapOrderFormsPortOverride');
		if (port_override)
			port = port_override;
			
		if ((port != '') && (port != null) &&  (port != undefined))
			url += ':' + port;

		jQuery.ajax(
		{
			type : 'POST',
			timeout: 2000,
			url : url,
			data: JSON.stringify(jsonArr),
			dataType: 'text',
			crossDomain: true,
			success: function(html,status,xhr) 
			{ 
				this._onSuccess(); 
			}.bind(this),
			error: function(xhr, status) 
			{ 
				this._onFailure();
			}.bind(this)
		});
		
		/*this._myRequest = new Request.LAWSONORDERFORM(
		{
			url: url,
			data: JSON.stringify(jsonArr),
			method: 'post',
			onSuccess: function(responseText, responseXML)
			{
				this._onSuccess();
			}.bind(this),
			onFailure: function()
			{
				this._onFailure();
			}.bind(this)				
		});
		this._myRequest.send();*/
	},
	
	_onSuccess : function()
	{
		var msg = Skin.getInstance().get('WhiteCapOrderFormsSentMsg','Your List has been sent');
		var title = Skin.getInstance().get('WhiteCapOrderFormsSentTitle','List Sent');
		Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:msg, title:title,callback:function()
		{
			this._popUpWindow.close();
		}.bind(this)});		
	},
	
	_onFailure : function()
	{
		var msg = Skin.getInstance().get('WhiteCapOrderFormsFailureMsg','Sorry, your request failed :(');
		var title = Skin.getInstance().get('WhiteCapOrderFormsFailureTitle','Send List Failed');
		Facade.getInstance().sendNotification(ApplicationFacade.ALERT_OK, {message:msg, title:title});
		
	},	
	
	_showSelectOrder : function()
	{
		this._popUpWindow.setContentSize(this._portraitWidth, this._portraitHeight);
		this._popUpWindow.center();
		this._popUpWindow.windowDiv.maximizeIcon.hide();
		this._popUpWindow.windowDiv.restoreIcon.hide();
		this._popUpWindow.windowDiv.resizeIcon.hide();
		
		if (Browser.Platform.desktop)
			this._popUpWindow.dragElement.detach();
			
		this._popUpWindow.windowDiv.header.setStyle('cursor', 'default');
		this._selectAddOrder();
		PopUpWindow.showModalOverlay();
		if (this._activeOrderFormName)
		{
			this._addOrderPanel_BackBtn.show();
			var windowTitle = this._activeOrderFormName;
			this._popUpWindow.setTitle(windowTitle);				
		}
		else
		{
			this._popUpWindow.setTitle('');
			this._addOrderPanel_BackBtn.hide();	
		}			
	},
	
	_showAddToCart : function()
	{
		this._popUpWindow.setContentSize(this._portraitWidth, this._portraitHeight);
		this._popUpWindow.center();
		this._popUpWindow.windowDiv.maximizeIcon.hide();
		this._popUpWindow.windowDiv.restoreIcon.hide();
		this._popUpWindow.windowDiv.resizeIcon.hide();

		if (Browser.Platform.desktop)
			this._popUpWindow.dragElement.attach();

		this._popUpWindow.windowDiv.header.setStyle('cursor', 'move');
		this._onAddList();
		
		if (this._activeOrderFormName)
		{
			var windowTitle = this._activeOrderFormName;
			this._popUpWindow.setTitle(windowTitle);				
		}
		else
		{
			this._popUpWindow.setTitle('');	
		}			
	},
	
	_showOrderMax : function()
	{
		var theSavePos = {};
		theSavePos.x = this._popUpWindow._restoreWindowPos.x;
		theSavePos.y = this._popUpWindow._restoreWindowPos.y;
		var theSaveSize = {};
		theSaveSize.x = this._popUpWindow._restoreContentSize.x;
		theSaveSize.y = this._popUpWindow._restoreContentSize.y;
		this._popUpWindow.setContentSize(this._minView_PortraitWidth, this._minView_PortraitHeight);
		this._popUpWindow.maximize();
		this._popUpWindow._restoreWindowPos = theSavePos;
		this._popUpWindow._restoreContentSize = theSaveSize;
		this._popUpWindow.center();
		this._popUpWindow.windowDiv.maximizeIcon.hide();
		this._popUpWindow.windowDiv.restoreIcon.show();
		this._popUpWindow.windowDiv.resizeIcon.hide();
		
		if (Browser.Platform.desktop)
			this._popUpWindow.dragElement.detach();
		
		this._popUpWindow.windowDiv.header.setStyle('cursor', 'default');
		PopUpWindow.showModalOverlay();
		this._onClickList();	
		if (this._activeOrderFormName)// && (this._data) && (!WhiteCapOrderForms.CartDialogActive))
		{
			var windowTitle = this._activeOrderFormName;
			this._popUpWindow.setTitle(windowTitle);				
		}
		else
		{
			this._popUpWindow.setTitle('');	
		}			
	},
	
	_showOrderMin : function()
	{
		this._popUpWindow.setContentSize(this._minView_PortraitWidth,this._minView_PortraitHeight);
		this._popUpWindow.restore();
		this._popUpWindow.windowDiv.maximizeIcon.show();
		this._popUpWindow.windowDiv.restoreIcon.hide();
		this._popUpWindow.windowDiv.resizeIcon.show();
		
		if (Browser.Platform.desktop)
			this._popUpWindow.dragElement.attach();
			
		this._popUpWindow.windowDiv.header.setStyle('cursor', 'move');
		PopUpWindow.hideModalOverlay();
		if (this._activeOrderFormName)
		{
			this._popUpWindow.setTitle(this._activeOrderFormName);				
		}
		else
		{
			this._popUpWindow.setTitle('');	
		}	
	},	
	
	_ie_comma_safety : 0	// Keep as last member of class (doesn't have trailing comma)
});

// Overriding Mootools Request class because the default headers values where preventing cross-domain request
Request.WHITECAPORDERFORM = new Class({

	Extends: Request,

	options: {
		headers: {'Accept': 'text/javascript, text/html, application/json, text/xml, */*'}
	},

	initialize: function(options){
		this.parent(options);

		Object.erase(this.headers, 'X-Requested-With');
	},
	
	isSuccess: function(){
		var status = this.status;
		return (status == 0 || (status >= 200 && status < 300));
	}

});
// ****************************************************************************
// ****************************************************************************
// Static variables 
// ****************************************************************************
// ****************************************************************************
WhiteCapOrderForms.CartDialogActive = false;

// ****************************************************************************
// ****************************************************************************
// Custom events used by this class
// ****************************************************************************
// ****************************************************************************
WhiteCapOrderForms.ReloadActiveOrderItems = 'WhiteCapOrderForms.ReloadActiveOrderItems';
WhiteCapOrderForms.ShowOrderMax = 'WhiteCapOrderForms.ShowOrderMax';
WhiteCapOrderForms.ShowOrderMin = 'WhiteCapOrderForms.ShowOrderMin';
WhiteCapOrderForms.CloseAddToCart = 'WhiteCapOrderForms.CloseAddToCart';

// ****************************************************************************
// ****************************************************************************
// Static Functions 
// ****************************************************************************
// ****************************************************************************
WhiteCapOrderForms._onPortOverride = function()
{
	var msg = Skin.getInstance().get('WhiteCapOrderFormsPortOverrideMsg','Please enter Port Number');
	var title = Skin.getInstance().get('WhiteCapOrderFormsPortOverrideTitle', 'Port Number');
	var defaultPort =  Skin.getInstance().get('WhiteCapOrderFormsDefaultPortNumber', '80');
	var override_port = Preferences.getInstance().get("WhiteCapOrderFormsPortOverride");
	if (override_port)
		defaultPort = override_port;
	
	Facade.getInstance().sendNotification(ApplicationFacade.LOAD_COMPONENT, {Name:'Ask', HasCss:true, Data:{Title:title, Message:msg, DefaultValue:defaultPort, Pattern:'[0-9]+$', InputLimitSize:'25', Callback:WhiteCapOrderForms._myAskCallback}});
},
	
WhiteCapOrderForms._myAskCallback = function(result)
{
	if (result)
		Preferences.getInstance().set("WhiteCapOrderFormsPortOverride",result);
},

// Shortcut hotkey to enable default port dialog
shortcut.add("Ctrl+Alt+e", WhiteCapOrderForms._onPortOverride);