// ----------------------------------------------------------------------------
// This View handles About Dialog
// ----------------------------------------------------------------------------
PDFembed = new Class(
{
	Extends: DialogView,

	// ************************************************************************
	// ************************************************************************
	//     MEMBER VARIABLES
	// ************************************************************************
	// ************************************************************************

	_appState: null,
	_abouteNotify: null,
	_spriteImage: null,
	_accordion: null,

	// ************************************************************************
	// ************************************************************************
	//     LIST OF PLUGIN ASSETS TO LOAD DYNAMICALLY
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// These functions return true if the <DynamicComponentName>-core.txt or 
	// <DynamicComponentName>-lang.txt files are present.
	// ------------------------------------------------------------------------
	hasSkinCoreAsset : function(){return true;},
	// If hasSkinLangAsset is true then _onChangeLanguage() is called when user changes languages (after language resources are loaded)
	hasSkinLangAsset : function(){return false;},

	// ------------------------------------------------------------------------
	// These functions return the list of plug-in assets to dynamically load for this component
	// ------------------------------------------------------------------------
	listJavascriptAssets : function(){return [];},
	listCssAssets : function(){return [];},
	
	// ------------------------------------------------------------------------
	// This function returns a path to an optional html asset to load for this component
	// ------------------------------------------------------------------------
	listHtmlAsset : function(){return 'PDFembed.html';},

	// ************************************************************************
	// ************************************************************************
	//     CONSTRUCTOR
	// ************************************************************************
	// ************************************************************************	

	initialize: function () 
	{
		this.parent('PDFembed', this);
		this._appState = Facade.getInstance().retrieveProxy(AppState.NAME);
	},

	// ------------------------------------------------------------------------
	// After LoadComponentCommand instantiates the component, then this function
	// is called to pass the arguments and actually create the DOM objects.
	//
	// Arguments: 
	//     theBasePath (String) - Contains the component base path
	//     theDialogData (Object) - Contains argument data for the dialog
	// ------------------------------------------------------------------------
	init: function (theBasePath, theDialogData) 
	{
		this.parent(theDialogData, 
		{
			basePath: theBasePath,
			title:  '',			// Need to set this in onContentLoaded so it will pick up translated title from the component skin
			width: 800,
			height: 800,
			_ie_comma_safety: 0 // Keep as last option (doesn't have trailing comma)
		});
	},
	
	onClose : function()
	{
		this.parent();
		// When coming back from the browser history button (which can happen here
		// if the user clicks the Open PDF button), IOS doesn't actually execute/reloaded 
		// code.  It just tries to reset the browser display state to what it was before.  
		// In this case, it causes a layout problem with the underlying page(s).  To
		// counteract this, we force a resize event after closing this dialog box (for
		// ios only).
		if (Browser.Platform.ios)
			Facade.getInstance().sendNotification.delay(1, Facade.getInstance(), ApplicationFacade.APPLICATION_RESIZED)		
	},

	// ************************************************************************
	// ************************************************************************
	//     PROTECTED FUNCTIONS
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// The Dialog DOM content (if any) is loaded by the time this function is
	// called so here we create and add any extra UIComponents and attach
	// event listeners.
	// ------------------------------------------------------------------------
	_onContentLoaded: function () 
	{
		this.parent();

		this._rootElement = this._widgetRootElement.getElement('#PDFembed_DialogContent');

		this._book = this._appState.get(currentBook);
		var sectionPath = this._book.getSectionHtmlFolder(this._book.getSectionIndex(this._appState.get(currentBookPageDest).BookPageIndex));

		this._pdfCheck = this._data.find('pdf').text();
		this._audioCheck = this._data.find('audio').text();

		if (Browser.Platform.desktop)
		{
			if (Browser.ie8)
			{
				Elements.from(
				'																						\
					<h1 style="text-align:center">This feature is not supported for this browser<h1>	\
				').inject(this._rootElement);
			}
			else if ((this._audioCheck != '') && (this._audioCheck != null) && (this._audioCheck != undefined))
			{
				Elements.from(
				'																																																									\
					<audio id="PDFembed_audioControls" controls style="position: absolute;top: 5px;width:100%;height: 30px">																												\
					<source id="PDFembed_audio" src="'+this._audioCheck+'" type="audio/mpeg">Your browser does not support the audio element.																							\
					</audio>																																																						\
					<embed id="PDFembed_pdf" src="'+this._pdfCheck+'" width="100%" height="100%" style="height: 95%;margin-top:40px" alt="pdf" wmode="transparent" pluginspage="http://www.adobe.com/products/acrobat/readstep2.html">	\
				').inject(this._rootElement);
			}
			else
			{
				Elements.from(
				'																																																									\
					<embed id="PDFembed_pdf" src="'+this._pdfCheck+'" width="100%" height="100%" style="height: 100%;margin-top:0px" alt="pdf" wmode="transparent" pluginspage="http://www.adobe.com/products/acrobat/readstep2.html">	\
				').inject(this._rootElement);
			}
		}
		else
		{
			Elements.from(
			'																																																									\
				<audio id="PDFembed_audioControls" controls style="position: relative;top: 5px;width:100%;height: 30px">																												\
				<source id="PDFembed_audio" src="'+this._audioCheck+'" type="audio/mpeg">Your browser does not support the audio element.																							\
				</audio>																																																						\
				<a href="'+this._pdfCheck+'" alt="pdf" class="btn btn-primary" style="margin-top:100px">Open PDF</a>	\
			').inject(this._rootElement);
		}

		this._show();
	},

	// ************************************************************************
	// ************************************************************************
	//
	// ************* Add Custom Functions and Event Handlers here *************
	//
	// ************************************************************************
	// ************************************************************************

	// ------------------------------------------------------------------------
	// Event handler for the click event on the image link
	// ------------------------------------------------------------------------


	_onChangeLanguage: function () 
	{

	},

	_ie_comma_safety: 0 // Keep as last member of class (doesn't have trailing comma)
});

// ****************************************************************************
// ****************************************************************************
// Constants used define the horizontal ordering of the button images in the sprite
// ****************************************************************************
// ****************************************************************************

PDFembed.ENOTIFY_SPRITE = 0;